<?php

/**
 * Filename: class-xenword-add-threadid.php
 *
 * Creates a new column and shows a link to the XenForo thread
 *
 * @author      LPH
 * @version     3.0.0.08
 * @package     XenWord
 * @subpackage  WordPress/admin/includes
 *
 * @since 3.0.0.08
 *        Initial release
 */

/**
 * This section is for security. Do not modify this part:
 *
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) { exit; }

class XenWord_AddThreadID {

	public function __construct() {

		$this->hooks();

	}

	public function hooks () {

		add_filter( 'manage_posts_columns', array( $this, 'add_thread_id' ) );
		add_action( 'manage_posts_custom_column', array( $this, 'show_columns' ) );
		add_filter( 'manage_edit-post_sortable_columns', array( $this, 'sort_columns' ) );

	}


	/**
	 * Add Thread_ID to Post Panel
	 *
	 * @param $columns
	 *
	 * @return mixed
	 *
	 * @since 1.0.0.8
	 */

	public function add_thread_id( $columns ) {
		$columns['threads'] = 'Threads';
		return $columns;
	}


	/**
	 *
	 * Show the new column in the post
	 *
	 * @param $name
	 */
	public function show_columns( $name ) {

		switch ( $name ) {
			case 'threads' :

				$post_id = '';
				$thread_id = XenWord::getThreadIdForPost($post_id);

				if ( ! empty( $thread_id ) && isset( $thread_id ) ) {

					echo '<a href="'
					     . XenForo_Link::buildPublicLink( 'canonical:threads', $thread_id )
					     . 'threads/' . $thread_id
					     . '"/>'
					     . $thread_id
					     . '</a>';
				}

		}
	}


	// Register the column as sortable
	public function sort_columns( $columns ) {
		$columns['threads'] = 'Threads';
		return $columns;
	}

}

new XenWord_AddThreadID();

// End class-xenword-add-threadid.php