<?php

/**
 * Filename: class-xenword-admin-notices.php
 *
 * @author  LPH
 * @version 2.5.0.04
 * @package XenWord
 * @subpackage includes
 *
 * @since 2.2.0.03
 *        Admin Notice can now be dismissed
 *
 * @since 3.0.0.03
 *        Change __construct to use $this->load_xenword_notices()
 *
 * @since 3.0.0.06
 *        Change public functions to public static functions
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWord_Admin_Notices {


	public function __construct() {

		$this->load_notices();

	}

	public function load_notices() {

		/**
		 * The add_action # is the menu position
		 * 10 = Before the WP Logo
		 * 15 = Between the logo and My Sites
		 * 25 = After the My Sites menu
		 * 100 = End of menu
		 */

		add_action( 'admin_notices', array( &$this, 'xenword_admin_notice') );

		add_action( 'admin_init', array( &$this, 'xenword_nag_ignore') );
	}

	/** Display a notice that can be dismissed */

	public static function xenword_admin_notice() {
		global $current_user, $pagenow;
		$user_id = $current_user->ID;

		/** Load the XenWord options set in XenWord settings panel */
		$xenword_options = get_option( 'xenword_options' );

		if( current_user_can( 'install_plugins' )  && $pagenow == 'admin.php' ) {
			if ( class_exists( 'XenForo_Application', false ) ) {

				/** Check that the user has not already clicked to ignore the message */
				if ( ! get_user_meta( $user_id, 'xenword_ignore_notice' ) ) {
					echo '<div class="updated"><p>';
					printf( __( 'XenWord '
					            . XENWORD_VERSION
					            . ' установлен. Это '
					            . XENWORD_RELEASE
					            . ' Версия. <br />Установленная версия XenForo является '
					            . XenForo_Application::$version
					            . ' <a href="admin.php?page=xenword">Settings</a> | <a href="%1$s">Скрыть уведомления</a>' ),
						'?xenword_nag_ignore=0' );
					echo "</p></div>";
				}
			} elseif ( ! file_exists( $xenword_options['absolute_path']
			                          . '/library/XenForo/Autoloader.php' )
			) {
				echo '<div class="updated"><p>';
				printf( __( 'XenWord '
				            . XENWORD_VERSION
				            . ' установлен. <br />Однако установленная версия XenForo не распознается. <a href="admin.php?page=xenword">Параметры</a> | <a href="%1$s">Скрыть уведомления</a>' ),
					'?xenword_nag_ignore=0' );
				echo "</p></div>";
			}
		}
	}


	public static function xenword_nag_ignore() {
		global $current_user;
		$user_id = $current_user->ID;

		/** If user clicks to ignore the notice, add that to their user meta */
		if ( isset( $_GET['xenword_nag_ignore'] )
		     && '0' == $_GET['xenword_nag_ignore']
		) {
			add_user_meta( $user_id, 'xenword_ignore_notice', 'true', true );
		}
	}
}

new XenWord_Admin_Notices();

// End class-xenword-admin-notices.php