<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'Redux' ) ) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "xenword_options";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

// $theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'      => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    // 'XenWord'              => $theme->get( 'Name' ),
    'display_name'          => 'XenWord',
    // Name that appears at the top of your panel
    // XENWORD_VERSION        => $theme->get( 'Version' ),
    'display_version'       => XENWORD_VERSION,
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => false,
    // Show the sections below the admin menu item or not
    'menu_title'           => __( 'XenWord', 'xenword' ),
    'page_title'           => __( 'XenWord Параметры', 'xenword' ),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => false,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => '100000',
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'options-general.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => 'dashicons-groups',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'xenword',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '', // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$args['admin_bar_links'][] = array(
    'id'    => 'redux-docs',
    'href'  => 'http://docs.reduxframework.com/',
    'title' => __( 'Документация', 'xenword' ),
);

$args['admin_bar_links'][] = array(
    //'id'    => 'redux-support',
    'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
    'title' => __( 'Поддержка', 'xenword' ),
);

$args['admin_bar_links'][] = array(
    'id'    => 'redux-extensions',
    'href'  => 'reduxframework.com/extensions',
    'title' => __( 'Расширения', 'xenword' ),
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
    'url'   => 'http://twitter.com/lph',
    'title' => 'Следуйте ЛПХ на Твиттере',
    'icon'  => 'el el-twitter'
);
$args['share_icons'][] = array(
    'url'   => 'http://www.google.com/profiles/layne.heiny',
    'title' => 'Следуйте ЛПХ на Google Plus',
    'icon'  => 'el el-googleplus'
);

// Panel Intro text -> before the form
if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
    if ( ! empty( $args['global_variable'] ) ) {
        $v = $args['global_variable'];
    } else {
        $v = str_replace( '-', '_', $args['opt_name'] );
    }
    $args['intro_text'] = sprintf( __( '<p>Простой мост между XenForo и WordPress.</p>', 'xenword' ), $v );
} else {
    $args['intro_text'] = __( '<p>Простой мост между XenForo и WordPress.</p>', 'xenword' );
}

// Add content after the form.
$args['footer_text'] = __( '<p><a href="http://www.xenword.com">XenWord</a> Простой мост между XenForo и WordPress.</p>', 'xenword' );

Redux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id'      => 'redux-help-tab-1',
        'title'   => __( 'Сведения о теме 1', 'xenword' ),
        'content' => __( '<p>Это содержимое вкладки HTML разрешен.</p>', 'xenword' )
    ),
    array(
        'id'      => 'redux-help-tab-2',
        'title'   => __( 'Сведения о теме 2', 'xenword' ),
        'content' => __( '<p>Это содержимое вкладки HTML допускается.</p>', 'xenword' )
    )
);
Redux::setHelpTab( $opt_name, $tabs );

// Set the help sidebar
$content = __( '<p>Это содержимое боковой панели, HTML разрешен.</p>', 'xenword' );
Redux::setHelpSidebar( $opt_name, $content );


/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

/*
	As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
 */

// -> START READ THIS FIRST
Redux::setSection( $opt_name, array(
    'title'            => __( 'СНАЧАЛА ПРОЧТИТЕ ЭТО', 'xenword' ),
    'id'               => 'readme',
    'desc'             => __( 'Этот раздел содержит важную информацию о XenWord', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'readme_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/readme.txt' )
        )
    ),
    'icon'             => 'el el-icon-glasses'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'readme-divide',
    'type' => 'divide',
) );

// -> START Absolute Path
Redux::setSection( $opt_name, array(
    'title'            => __( 'Абсолютный путь', 'xenword' ),
    'id'               => 'path',
    'desc'             => __( 'Задайте абсолютный путь к XenForo', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'absolute_path',
            'type'      => 'text',
            'title'     => __('Введите XenForo абсолютный путь', 'xenword'),
            'desc'      => __('Это должен быть абсолютный путь к XenForo установке.
                                            Не включайте конечные  "/" или "index.php".
                                            Использовать phpinfo () доступны в XenForo admin
                                            (domain.com/path/to/XenForo/admin.php?tools/phpinfo).
                                            <p><h3>Пример 1:</h3>
                                            /var/www/domain.com/html<br />
                                            </p>
                                            <p><h3>Пример 2:</h3>
                                            /var/www/home/community<br />
                                            </p>
		                                    ', 'xenword'),
            'default'   => '/var/www/home/community'
        ),
        array(
            'id'       => 'xf_path_instructions',
            'type'     => 'info',
            'style' => 'critical',
            'desc'      => 'WordPress и XenForo должны быть на том же физическом сервере, а также использовать то же имя домена.

	            		<p>Поддомене конфигурация требует изменений в path/to/xenforo/library/config.php
		                file in XenForo.

		                <a href="http://xenforo.com/community/threads/xenforos-handing-of-cookie-domains.15260/#post-200173">Параметры файлов cookie</a>
		                необходимо изменить, а затем очистить ваш браузер. Далее задайте URL-адрес платы для дочернего домена после того, как вы протестировали логины.<br />
		                </p>
		                Для получения дополнительной информации, пожалуйста, прочитайте XenWord документацию на <a href="http://www.tuxreports.com/community/xenword/xenword-absolute-path.4/">абсолютный путь</a>.',
        ),
        array(
            'id'        => 'wrong_absolute',
            'type'      => 'info',
            'style'     => 'warning',
            'desc'      => 'Если виджеты не работают вы скорее всего, не правильный путь сохранили. Пожалуйста, используйте phpinfo (), чтобы найти абсолютный путь. Посмотрите на информацию рядом с _SERVER[SCRIPT_FILENAME]'
        ),
    ),
    'icon'             => 'el el-icon-warning-sign'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-user-divide',
    'type' => 'divide',
) );


// -> START User System
Redux::setSection( $opt_name, array(
    'title'            => __( 'Система пользователя', 'xenword' ),
    'id'               => 'user_system',
    'desc'             => __( 'Параметры для пользователя системы XenWord  !', 'xenword' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-icon-user'
) );


// -> START User Permissions
Redux::setSection( $opt_name, array(
    'title'            => __( 'Включено / выключено переключатели', 'xenword' ),
    'id'               => 'users',
    'subsection'       => true,
    'desc'             => __( 'Задайте параметры для аватаров, перенаправления', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(

        array(
            'id'        => 'use_wp_users',
            'type'      => 'switch',
            'title'     => __('WordPress пользователи панели', 'xenword'),
            'desc'      => __('Переключиться к дальше, если вы хотите использовать панель WordPress пользователей.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_add_users',
            'type'      => 'switch',
            'title'     => __('Добавить XenForo пользователей в базе данных WordPress', 'xenword'),
            'desc'      => __('Перейти дальше, если вы хотите добавить пользователей XenForo таблицу пользователей WordPress.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'wp_version_45',
            'type'      => 'switch',
            'title'     => __('WordPress версия 4.5', 'xenword'),
            'desc'      => __('Переключиться на Если у вас есть версия WordPress4.5.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
    ),
    'icon'             => 'el el-off'
) );


// -> START Default User
Redux::setSection( $opt_name, array(
    'title'            => __( 'Пользователь по умолчанию', 'xenword' ),
    'id'               => 'user_mapping',
    'subsection'       => true,
    'desc'             => __( 'Задать роль пользователя по умолчанию для всех членов XenForo', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'xf_user_role_info',
            'type'      => 'info',
            'style'     => 'critical',
            'desc'      => 'Сопоставление разрешений пользователей резко изменилась под XenWord 2.5. Если расширенные сопоставления все WordPress роли назначаются администратором WP на уровне пользователя. Пользователь только копируется из XenForo до WorddPress после входа на сайт и просмотреть, WordPress',
        ),
        array(
            'id'        => 'wp_default_role',
            'type'      => 'select',
            'title'     => __('Введите роль WordPress по умолчанию', 'xenword'),
            'data'      => 'roles',
            'default'   => 'subscriber'
        ),

    ),
    'icon'             => 'el el-icon-user'
) );

// -> START Advanced User Mapping

$xen_ids = xenwordGetUGIds();

$field_arr = array(
    array(
        'id'    => 'xf_adv_mapping_info',
        'type'  => 'info',
        'style' => 'info',
        'desc'  => 'Расширенное сопоставление позволяет WordPress роли назначаемое на основе выбора XenForo группы. Это только альфа-код и не должен использоваться на рабочем сервере',
    ),
    array(
        'id'      => 'use_adv_mapping',
        'type'    => 'switch',
        'title'   => __( 'Включить расширенное сопоставление', 'xenword' ),
        'desc'    => __( 'Включить для сопоставления роли WordPress и XenForo вторичных групп пользователей.', 'xenword' ),
        'default' => false // true = on | false = off
    ),
);

if ( class_exists( 'XenForo_Application' ) ) {
    foreach ( $xen_ids as $id => $title ) {
        $field_to_add = array(
            'id'      => 'xf_role_' . $id,
            'type'    => 'select',
            'title'   => __( $title, 'xenword' ),
            //'data'      => 'roles',
            'options' => xenword_wp_roles(),
            'default' => $xenword_options['xf_user_role'][ $id ]
        );

        array_push( $field_arr, $field_to_add );
    }


    Redux::setSection( $opt_name, array(
        'title'            => __( 'Сопоставление пользователей', 'xenword' ),
        'id'               => 'adv_user_mapping',
        'subsection'       => true,
        'desc'             => __( 'Сопоставление опытных пользователей это только альфа-код. Не используйте на рабочем сервере',
            'xenword' ),
        'customizer_width' => '400px',
        'fields'           => $field_arr,
        'icon'             => 'el el-icon-user'
    ) );
}


// -> START Avatars
Redux::setSection( $opt_name, array(
    'title'            => __( 'Аватары', 'xenword' ),
    'id'               => 'avatars',
    'subsection'       => true,
    'desc'             => __( '<p class="description">Показать аватары XenForo на WordPress установки. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'avatars_code_version',
            'type'      => 'switch',
            'title'     => __('Версия WordPress', 'xenword'),
            'desc'      => __('Перейти к дальше, если вы хотите использовать XenForo аватары с WordPress 4.4. Держите для использования с версией 4.3', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'xf_sync_avatars',
            'type'      => 'switch',
            'title'     => __('Синхронизировать аватары', 'xenword'),
            'desc'      => __('Переключиться на Если вы хотите использовать XenForo аватары с WordPress.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
    ),
    'icon'             => 'el el-icon-user'
) );

// -> START Authors
Redux::setSection( $opt_name, array(
    'title'            => __( 'Авторы', 'xenword' ),
    'id'               => 'authors',
    'subsection'       => true,
    'desc'             => __( '<p class="description">Показать информацию автора XenForo на WordPress установке. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_author_link',
            'type'      => 'switch',
            'title'     => __('Автор перенаправление', 'xenword'),
            'desc'      => __('Переключиться на перенаправление WordPress автора ссылку на профиль пользователя XenForo и сообщения.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_xf_profile',
            'type'      => 'switch',
            'title'     => __('XenForo профиль автора ', 'xenword'),
            'desc'      => __('Переключиться на  Если вы хотите использовать профиль exfcnybrf XenForo, используемый в коробке автора био.', 'xenword'),
            'default'   => true // true = on | false = off
        ),

    ),
    'icon'             => 'el el-icon-user'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-thread-divide',
    'type' => 'divide',
) );


// -> START Thread System
Redux::setSection( $opt_name, array(
    'title'            => __( 'Система потоков', 'xenword' ),
    'id'               => 'thread_system',
    'desc'             => __( 'Параметры для XenForo темы форума!', 'xenword' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-pencil'
) );

// --> START Thread Creation
Redux::setSection( $opt_name, array(
    'title'            => __( 'Главная/выключатель', 'xenword' ),
    'id'               => 'thread_creation',
    'subsection'       => true,
    'desc'             => __( 'Эти опции включить или отключить функции создания потока', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_thread_creation',
            'type'      => 'switch',
            'title'     => __('Используйте систему создания потоков.', 'xenword'),
            'desc'      => __('Это позволяет использовать систему создания потоков.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_tag_creation',
            'type'      => 'switch',
            'title'     => __('Используйте систему создания тегов.', 'xenword'),
            'desc'      => __('Это позволяет WordPress теги для добавления к сообщению XenForo.', 'xenword'),
            'default'   => false // true = on | false = off
        ),

        array(
            'id'   => 'info_scheduled_thread',
            'type' => 'info',
            'style'     => 'info',
            'desc' => __('Запланированные должности будут размещать на WordPress, но не будет создан поток.', 'xenword')
        ),
    ),
    'icon'             => 'el el-off'
) );

// -> START WordPress Post
Redux::setSection( $opt_name, array(
    'title'            => __( 'WP Пост', 'xenword' ),
    'id'               => 'wp_post_settings',
    'subsection'       => true,
    'desc'             => __('Включение создания потока для WordPress пост', 'xenword'),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_thread_creation_post',
            'type'      => 'switch',
            'title'     => __('Создайте поток для Post.', 'xenword'),
            'desc'      => __('Создайте новый поток XenForo из новых WordPress постов.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'first_post_contains',
            'type'      => 'select',
            'title'     => __('Содержит первый пост XenForo', 'xenword'),

            //Must provide key => value pairs for select options
            'options'   => array(
                '1' => 'full',
                '2' => 'excerpt',
                '3' => 'custom excerpt',
                '4' => 'link'
            ),
            'default'   => '2'
        ),
        array(
            'id'        => 'xf_excerpt_length',
            'type'      => 'text',
            'title'     => __('Длина пользовательской выдержки', 'xenword'),
            'desc'      => __('Введите длину пользовательского выдержка для первого поста XenForo.', 'xenword'),
            'default'   => '55'
        ),
    ),
    'icon'             => 'el el-list'
) );

// -> START WordPress Page
Redux::setSection( $opt_name, array(
    'title'            => __( 'WP Страница', 'xenword' ),
    'id'               => 'wp_page_settings',
    'subsection'       => true,
    'desc'             => __('Включение создания потока для WordPress пост', 'xenword'),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_thread_creation_page',
            'type'      => 'switch',
            'title'     => __('Создание потока для страницы', 'xenword'),
            'desc'      => __('Создайте новый поток XenForo из новой страницы в WordPress.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
    ),
    'icon'             => 'el el-list'
) );

// -> START WordPress Custom Post
Redux::setSection( $opt_name, array(
    'title'            => __( 'Пользовательские WP пост', 'xenword' ),
    'id'               => 'wp_custom_post_settings',
    'subsection'       => true,
    'desc'             => __('Включение создания потока для WordPress пост', 'xenword'),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_thread_creation_custom',
            'type'      => 'switch',
            'title'     => __('Создайте поток для таможенный пост', 'xenword'),
            'desc'      => __('Создайте новый поток XenForo из новых WordPress пользовательских сообщений.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'       => 'custom_post_type',
            'type'     => 'select',
            'multi'    => 'true',
            'title'    => __('Выберите тип настраиваемого сообщения', 'xenword'),
            'desc'     => __('Список типов различных post. Вы можете выбрать несколько пользовательских типов должность', 'xenword'),
            // Must provide key => value pairs for select options
            'data'     => 'post_types'
        ),
    ),
    'icon'             => 'el el-list'
) );

// -> START Default Forum
Redux::setSection( $opt_name, array(
    'title'            => __( 'По умолчанию форум', 'xenword' ),
    'id'               => 'default_forum_settings',
    'subsection'       => true,
    'desc'             => __('Включение по умолчанию форум требует настройки по умолчанию форума и будет остановить писать WordPress постов на всех других форумах', 'xenword'),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_default_forum',
            'type'      => 'switch',
            'title'     => __('Использовать форум по умолчанию.', 'xenword'),
            'desc'      => __('Это позволяет по умолчанию форум для использования.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'default_forum',
            'type'      => 'text',
            'title'     => __('Введите форум по умолчанию', 'xenword'),
            'desc'      => __('Это форум по умолчанию для всех новых сообщений.', 'xenword'),
            'default'   => '2'
        ),
    ),
    'icon'             => 'el el-list'
) );

// -> START Thread Texts
Redux::setSection( $opt_name, array(
    'title'            => __( 'Проденьте тексты', 'xenword' ),
    'id'               => 'thread_texts',
    'subsection'       => true,
    'desc'             => __( 'Изменить текст размещен с каждой новой записи блога', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(

        array(
            'id'   => 'info_normal',
            'type' => 'info',
            'style'     => 'info',
            'desc' => __('Следующий текст отображается в XenForo форум ссылок на статью WordPress.', 'xenword')
        ),
        array(
            'id'        => 'use_submission_text',
            'type'      => 'switch',
            'title'     => __('Отображение представления текста в XenForo потоке', 'xenword'),
            'desc'      => __('Показать представление текста в потоке XenForo.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'submission_text',
            'type'      => 'text',
            'title'     => __('Введите текст представления', 'xenword'),
            'desc'      => __('Фраза появится с XenForo темой.', 'xenword'),
            'default'   => 'submitted a new blog post'
        ),
        array(
            'id'        => 'use_title_text',
            'type'      => 'switch',
            'title'     => __('Показать название блога в XenForo потоке', 'xenword'),
            'desc'      => __('Показать фразу в новом потоке XenForo.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'continue_text',
            'type'      => 'textarea',
            'title'     => __('Введите далее текст', 'xenword'),
            'subtitle'  => __('BBCode допускается'),
            'desc'      => __('Фраза появится с XenForo темой.', 'xenword'),
            'validate'  => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
            'default'   => 'Continue reading the Original Blog Post.'
        ),
    ),
    'icon'             => 'el el-list'
) );

// --> START Category / Forum Mapping

// -> START Thread Link
Redux::setSection( $opt_name, array(
    'title'            => __( 'Поток ссылка', 'xenword' ),
    'id'               => 'thread_link',
    'desc'      => __('Включить или отключить ссылку на обсуждение в XenForo.', 'xenword'),
    'subsection'       => true,
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_thread_link',
            'type'      => 'switch',
            'title'     => __('Показать ссылку на XenForo поток', 'xenword'),
            'desc'      => __('Показать ссылку на XenWord обсуждение в конце поста WordPress содержание.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'discussion_text',
            'type'      => 'text',
            'title'     => __('Введите текст для обсуждения ссылки', 'xenword'),
            'desc'      => __('Фраза появится ниже WordPress статьи.', 'xenword'),
            'default'   => 'Обсудить в нашем сообществе'
        ),
        array(
            'id'        => 'use_comment_link',
            'type'      => 'switch',
            'title'     => __('Использовать количество комментариев в качестве ссылки', 'xenword'),
            'desc'      => __('Показать количество комментариев как ссылку. Изменить текст обсуждения слово Комментарии.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
    ),
    'icon'             => 'el el-list'
) );

// -> START Featured Image
Redux::setSection( $opt_name, array(
    'title'            => __( 'Рекомендуемые изображение', 'xenword' ),
    'id'               => 'featured',
    'subsection'       => true,
    'desc'             => __( '<p class="description">Показать изображение WordPress признакам в XenForo потоке. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_featured_image',
            'type'      => 'switch',
            'title'     => __('WordPress лучшее изображение', 'xenword'),
            'desc'      => __('Показать изображение WordPress признакам в потоке XenForo.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_large_featured_image',
            'type'      => 'switch',
            'title'     => __('Большое изображение WordPress признакам', 'xenword'),
            'desc'      => __('Включите, чтобы разместить большой версии WordPress признакам изображения в потоке XenForo.', 'xenword'),
            'default'   => true // true = on | false = off
        )
    ),
    'icon'             => 'el el-picture'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-comments-divide',
    'type' => 'divide',
) );

// -> START Comment System
Redux::setSection( $opt_name, array(
    'title'            => __( 'Система комментариев', 'xenword' ),
    'id'               => 'comment_system',
    'desc'             => __( 'Это параметры темы форума XenForo!', 'xenword' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-speaker'
) );

// -> START Comment Switch On/Off
Redux::setSection( $opt_name, array(
    'title'            => __( 'Главный On/Off Переключатель', 'xenword' ),
    'id'               => 'comments_switch',
    'subsection'       => true,
    'desc'             => __( '<p class="description">Этот параметр будет применяться только на сообщения, сделанные после того, как был установлен этот аддон.
							</p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_comment_system',
            'type'      => 'switch',
            'title'     => __('Включите комментарий.', 'xenword'),
            'desc'      => __('Все комментарии будут отображаться на блог и форум.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'   => 'info_comment_system',
            'type' => 'info',
            'style'     => 'critical',
            'desc' => __('Этот параметр допустим только в том случае, если система создания потока.', 'xenword')
        ),

    ),
    'icon'             => 'el el-off'
) );

// -> START Comment Display Options
Redux::setSection( $opt_name, array(
    'title'            => __( 'Параметры отображения', 'xenword' ),
    'id'               => 'display_options',
    'subsection'       => true,
    //'desc'             => __( '<p class="description">Show the WordPress featured image in a XenForo thread. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_comment_order',
            'type'      => 'select',
            'title'     => __('Порядок комментов ', 'xenword'),
            'desc'      => __('Выберите новые или старые комментарии появляются в верхней части раздела комментариев. Это должно соответствовать параметрам в WordPress обсуждения
				area.'),

            //Must provide key => value pairs for select options
            'options'   => array(
                '1' => 'older',
                '2' => 'newer'
            ),
            'default'   => '2'
        ),
        array(
            'id'        => 'display_comments_in_wp',
            'type'      => 'switch',
            'title'     => __('Отображение комментариев в WordPress.', 'xenword'),
            //'desc'      => __('Включить комментарии.', 'xenword'),
            'default'   => 'true'// true = on | false = off
        ),
        array(
            'id'        => 'comments_per_page',
            'type'      => 'text',
            'title'     => __('Ввод комментариев на страницу', 'xenword'),
            'desc'      => __('Это переопределяет параметр WordPress.', 'xenword'),
            'default'   => '20'
        ),
    ),
    'icon'             => 'el el-picture'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-toolbar-divide',
    'type' => 'divide',
) );

// -> START WordPress Toolbar
Redux::setSection( $opt_name, array(
    'title'            => __( 'WordPress панели инструментов', 'xenword' ),
    'id'               => 'toolbar',
    'desc'             => __( '<p class="description">XenForo предоставляет членам предупреждений и разговор</p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_wordpress_toolbar',
            'type'      => 'switch',
            'title'     => __('Показать панель инструментов WordPress.', 'xenword'),
            'desc'      => __('Включение и отключение панели инструментов WordPress для всех новых пользователей XF. Роль по умолчанию необходимо задать для всех новых пользователей.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_xenword_conversations',
            'type'      => 'switch',
            'title'     => __('Показать XenForo разговоры.', 'xenword'),
            'desc'      => __('Включить или выключить показ XenForo разговоров на WordPress панели инструментов.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_xenword_alerts',
            'type'      => 'switch',
            'title'     => __('Показывать предупреждения XenForo.', 'xenword'),
            'desc'      => __('Включить или выключить показ XenForo оповещения на панели инструментов WordPress.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_xenword_likes',
            'type'      => 'switch',
            'title'     => __('Показать XenForo Likes.', 'xenword'),
            'desc'      => __('Включение и отключение показывая пользовательские Лайки на WordPress панели инструментов.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'use_xenword_toolbar_settings',
            'type'      => 'switch',
            'title'     => __('Показать ссылку настройки XenWord.', 'xenword'),
            'desc'      => __('Включить или отключить ссылку XenWord настройки на панели инструментов WordPress.', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'   => 'info_WordPress_Toolbar_css',
            'type' => 'info',
            'style'     => 'info',
            'desc' => __('
                        <a href="https://developer.wordpress.org/resource/dashicons/">Dashicons</a>
		                можно добавить до разговоров, оповещения и любит, добавив надлежащую информацию для
		                Тема WordPress через xenword.css, найденных в каталоге администратора.<br />
		                ', 'xenword')
        )
    ),
    'icon'             => 'el el-wordpress'
) );


// -> START WordPress Widgets Section
Redux::setSection( $opt_name, array(
    'title'            => __( 'WordPress Виджеты', 'xenword' ),
    'id'               => 'wordpress_widgets',
    'desc'             => __( '<p class="description">Задайте параметры для WordPress Логин виджет. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_facebook',
            'type'      => 'switch',
            'title'     => __('Facebook Социальный логин', 'xenword'),
            'desc'      => __('Показать логин Facebook социальные.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_twitter',
            'type'      => 'switch',
            'title'     => __('Твиттер Социальный логин', 'xenword'),
            'desc'      => __('Показать Twitter социальный логин.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_google',
            'type'      => 'switch',
            'title'     => __('Google социальные логин', 'xenword'),
            'desc'      => __('Показать логин Google социальные.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
    ),
    'icon'             => 'el el-wordpress'
) );

// -> START XenForo Addons Section
Redux::setSection( $opt_name, array(
    'title'            => __( 'XenForo аддоны', 'xenword' ),
    'id'               => 'xenforo_addons',
    'desc'             => __( '<p class="description"> Задать параметры для некоторых виджетов XenWord когда установлены другие дополнения XenForo. </p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_ams',
            'type'      => 'switch',
            'title'     => __('Система управления статьи', 'xenword'),
            'desc'      => __('Установлен на АМС, если установлен и активен.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_media',
            'type'      => 'switch',
            'title'     => __('XenForo Медиа-Галерея', 'xenword'),
            'desc'      => __('Установлено, если XenForo Медиа-Галерея установлена и активна.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_postratings',
            'type'      => 'switch',
            'title'     => __('Пост рейтинги', 'xenword'),
            'desc'      => __('Установлено, если размещать рейтинги установлен и активен.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_showcase',
            'type'      => 'switch',
            'title'     => __('Витрина', 'xenword'),
            'desc'      => __('Установлено, если Витрина установлено и активно.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'use_xenreviews',
            'type'      => 'switch',
            'title'     => __('Xen Отзывы', 'xenword'),
            'desc'      => __('Установить на если XenReviews установлен и активен.', 'xenword'),
            'default'   => false // true = on | false = off
        ),
    ),
    'icon'             => 'el el-flag'
) );


// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-multisite-divide',
    'type' => 'divide',
) );

// -> START Multisite
Redux::setSection( $opt_name, array(
    'title'            => __( 'Многосайтовой настройки', 'xenword' ),
    'id'               => 'multisite',
    'desc'             => __( 'Эти опции включить или отключить функции создания потока', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'use_multisite',
            'type'      => 'switch',
            'title'     => __('Используйте настройки многосайтовой.', 'xenword'),
            'desc'      => __('', 'xenword'),
            'default'   => true // true = on | false = off
        ),
        array(
            'id'        => 'multisite_admins',
            'type'      => 'text',
            'title'     => __('Введите XenForo имена пользователей для администраторов', 'xenword_options'),
            'desc'      => __('', 'xenword_options'),
            'default'   => 'LPH, RWH'
        ),
    ),
    'icon'             => 'el el-globe'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-options-divide',
    'type' => 'divide',
) );

// -> START Error Reporting
Redux::setSection( $opt_name, array(
    'title'            => __( 'Отчеты об ошибках', 'xenword' ),
    'id'               => 'errors',
    'desc'             => __( '<p class="description">Включение или отключение отчетов об ошибках.</p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'enable_error_reporting',
            'type'      => 'switch',
            'title'     => __('Включение отчетов об ошибках.', 'xenword'),
            'desc'      => __('Переключиться на Да.', 'xenword'),
            'on'        => 'Да',
            'off'       => 'Нет',
            'default'   => false // true = on | false = off
        )
    ),
    'icon'             => 'el el-wrench'
) );

// -> DIVIDER
Redux::setSection( $opt_name, array(
    'id'   => 'xenword-error-options-divide',
    'type' => 'divide',
) );

// -> START Information System
Redux::setSection( $opt_name, array(
    'title'            => __( 'Информационная система', 'xenword' ),
    'id'               => 'info_system',
    'desc'             => __( 'Эти вкладки предназначены для XenWord информационной системы  !', 'xenword' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-info-circle'
) );

// -> START FAQs Section
Redux::setSection( $opt_name, array(
    'title'            => __( 'FAQs', 'xenword' ),
    'id'               => 'faqs',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'faqs_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/faqs.txt' )
        )
    ),
    'icon'             => 'el el-info-circle'
) );

// -> START Video Tutorials
Redux::setSection( $opt_name, array(
    'title'            => __( 'Video Учебники', 'xenword' ),
    'id'               => 'video',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'tutorials_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/tutorials.txt' )
        )
    ),
    'icon'             => 'el el-info-circle'
) );

// -> START Changelog
Redux::setSection( $opt_name, array(
    'title'            => __( 'История изменений', 'xenword' ),
    'id'               => 'changelog',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'changelog_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/changelog.txt' )
        ),
    ),
    'icon'             => 'el el-info-circle'
) );

// -> START Roadmap
Redux::setSection( $opt_name, array(
    'title'            => __( 'Дорожная карта', 'xenword' ),
    'id'               => 'roadmap',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'roadmap_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/roadmap.txt' )
        )
    ),
    'icon'             => 'el el-info-circle'
) );

// -> START About
Redux::setSection( $opt_name, array(
    'title'            => __( 'Об плагине', 'xenword' ),
    'id'               => 'about',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'about_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/about.txt' )
        )
    ),
    'icon'             => 'el el-info-circle'
) );

// -> START Branding Options
Redux::setSection( $opt_name, array(
    'title'            => __( 'Брендирование параметры', 'xenword' ),
    'id'               => 'branding',
    'subsection'       => true,
    'desc'             => __( '<p class="description">Ссылка XenWord может быть изменен, но пожалуйста, не удаляйте его если нет
                купил брендинг безвозмездную лицензию.</p>', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'        => 'remove_branding',
            'type'      => 'switch',
            'title'     => __('Удалите ссылку на XenWord.', 'xenword'),
            'desc'      => __('Переключитесь на Да, если вы приобрели брендинг безвозмездную лицензию.', 'xenword'),
            'on'        => 'Да',
            'off'       => 'Нет',
            'default'   => false // true = on | false = off
        ),
        array(
            'id'        => 'xenword_footer_text',
            'type'      => 'textarea',
            'title'     => __('Введите текст нижнего колонтитула', 'xenword'),
            'subtitle'  => __('HTML разрешено'),
            'desc'      => __('Фраза появится в нижнем колонтитуле WordPress.', 'xenword'),
            'validate'  => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
            'default'   => 'Этот сайт использует <a href="http://www.xenword.com">XenWord</a>.'
        ),
        array(
            'id'        => 'xenword_branding_color',
            'type'      => 'color',
            'title'     => __('Цвет текста', 'xenword'),
            'subtitle'  => __('Выберите цвет текста.', 'xenword'),
            'default'   => '#dd9933',
            'output'    => array('color' => 'div.xenword_branding')
        ),
    ),
    'icon'             => 'el el-fire'
) );

// -> START License
Redux::setSection( $opt_name, array(
    'title'            => __( 'Лицензия', 'xenword' ),
    'id'               => 'license',
    'subsection'       => true,
    'desc'             => __( '', 'xenword' ),
    'customizer_width' => '400px',
    'fields'    => array(
        array(
            'id'       => 'license_raw',
            'type'     => 'raw',
            'content'  => file_get_contents(dirname(__FILE__) . '/license.txt' )
        )
    ),
    'icon'             => 'el el-info-circle'
) );

/*
 * <--- END SECTIONS
 */


/*
 *
 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
 *
 */

/*
*
* --> Action hook examples
*
*/

// If Redux is running as a plugin, this will remove the demo notice and links
add_action( 'redux/loaded', 'remove_demo' );

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if ( ! function_exists( 'remove_demo' ) ) {
    function remove_demo() {
        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
            remove_filter( 'plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2 );

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
        }
    }
}

function xenword_wp_roles() {
    require_once ABSPATH . 'wp-admin/includes/user.php';
    $roles_arr = array();

    $editable_roles = array_reverse( get_editable_roles() );

    foreach ( $editable_roles as $role => $details ) {
        $name = translate_user_role( $details['name'] );


        $roles_arr[ $role ] = $name;
    }

    return $roles_arr;

}

function xenwordGetUGIds() {
    $idArr = array();

    if ( class_exists( 'XenForo_Model' ) ) {
        /** @var $UGModel XenForo_Model_UserGroup */
        $UGModel    = XenForo_Model::create( 'XenForo_Model_UserGroup' )->getModelFromCache( 'XenForo_Model_UserGroup' );
        $usergroups = $UGModel->getAllUserGroups();

        foreach ( $usergroups as $usergroup ) {
            $id           = $usergroup['user_group_id'];
            $title        = $usergroup['title'];
            $idArr[ $id ] = $title;
        }

        asort( $idArr );

        return $idArr;
    }
}