<?php
/**
 * Filename: class-xenword-activator.php
 *
 * Contains register_activation_hook and add_action wpmu_new_blog
 *
 * These functions alter the posts and comments WordPress table by adding thread_id
 *
 * @author  LPH
 * @version 2.5.0.04
 * @package XenWord
 * @subpackage WordPress/includes
 *
 * functions xenword_activate()
 *
 * function xenword_add_new_site($blog_id)
 *
 * @since 2.5.1.02
 *        Removed $result variable
 *
 * @since 3.0.0.03
 *        Wrap add_action with is_multisite conditional
 *
 * @since 3.0.0.06
 *        Rewrote the activate() method
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 */
class Xenword_Activator {

	public function __construct() {

		if ( is_multisite() ) {
			add_action( 'wpmu_new_blog', array( &$this, 'xenword_add_new_site', 10, 1 ) );
		}
	}

	/**
	 * Alters post and comments table by adding new columns to the WordPress database
	 * The new wp_post columns include forum_id, thread_id, resource_category_id, resource_id
	 * The new wp_users column includes xf_user_id
	 * The new wp_comments column includes XF_post_ID
	 *
	 * In multisite, calls xenword_add_new_site
	 *
	 * @since 1.0.0
	 */
	public static function activate() {

		global $wpdb;

		add_option( 'xenword_options' );

		$comments_qry = $wpdb->get_row( "SELECT * FROM $wpdb->users" );

		if ( ! isset( $comments_qry->XF_post_ID ) ) {
			$wpdb->query( "ALTER TABLE {$wpdb->comments} ADD `XF_post_ID` INT( 10 ) UNSIGNED NOT NULL DEFAULT '0' AFTER `comment_post_ID` " );
		}

		/**
		 * Added && $network_wide
		 */

		if ( is_multisite() ) {
			/** @var  $sites */
			$sites = $wpdb->get_results( "SELECT {blog_id} FROM {$wpdb->prefix}blogs" );

			foreach ( $sites as $site ) {
				$blog_id = $site->blog_id;
				if ( $blog_id != 1 ) {
					Xenword_Activator::xenword_add_new_site( $blog_id );
				}
			}
		}

		/**
		 * Logout sessions in WordPress and XenForo
		 *
		 * @since 3.0.0.06
		 */

		if ( class_exists( 'XenForo_Autoloader' ) ) {

			$user_id = XenWord::getVisitor()->getUserId();

			// get all sessions for user with ID $user_id
			$sessions = WP_Session_Tokens::get_instance( $user_id );

			// we have got the sessions, destroy them all!
			$sessions->destroy_all();

			XenWord::getLogout();
		}
		
		return;
	}

	/**
	 * Function xenword_add_new_site
	 *
	 * @param $blog_id
	 */

	public static function xenword_add_new_site( $blog_id ) {
		global $wpdb;

		add_option( 'xenword_options' );

		$comments_qry = $wpdb->get_row( "SELECT * FROM $wpdb->users" );

		if( !isset( $comments_qry->XF_post_ID ) ) {
			$wpdb->query( "ALTER TABLE {$wpdb->prefix}{$blog_id}_comments ADD `XF_post_ID` INT( 10 ) UNSIGNED NOT NULL DEFAULT '0' AFTER `comment_post_ID` " );
		}

		return;
	}
	
}

// End of class-xenword-activator.php