<?php

/**
 * Filename: class-xenword-add-wpusers.php
 *
 * class XenWord_AddWPUsers contains one function, xenword_add_wp_user()
 * The function adds the XenForo users to the WordPress tables users and usermeta.
 *
 * @author  LPH
 * @version 2.5.0.04
 * @package XenWord
 * @subpackage includes
 *
 * @since 1.0.6
 * Insert the current user into the wp_users and wp_usermeta table
 *
 * @since 1.0.7
 * Moved this code to a separate function.
 *
 * @since 2.0.1.02
 * Added default role chosen in XenWord panel via $role_userdata
 *
 * @since 2.5.0.02
 * Conditionals to configure WP default role and permissions based on XenForo Secondary Usergroup
 * Cleaned up $role_userdata
 *
 * @since 2.5.1.01
 *        Returned $role_userdata
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * wp_update_user()
 * update_user_meta()
 *
 */

class XenWord_XF_Users {

	public function __construct() {
		//$this->xenword_add_wp_user();
	}

	public static function check_options() {

		/** Load the XenWord options set in XenWord settings panel */
		$xenword_options = get_option( 'xenword_options' );

		if ( $xenword_options['use_add_users'] == true ) {

			XenWord_XF_Users::role();

		} else {

			return false;
		}

	}

	public static function role() {

		$visitor = XenWord::getVisitor();
		$xenword_options = get_option( 'xenword_options' );

		if ( $xenword_options['use_adv_mapping'] == true ) {

			// This is a string array separated by commas
			$userGroupIds = $visitor['secondary_group_ids'];
			$userGroups = explode(',', $userGroupIds);

			foreach ( $userGroups as $userGroupId ) {
				$xf_role = 'xf_role_' . $userGroupId;
				$wp_role = $xenword_options[$xf_role];
			}

			// Zend_Debug::dump($wp_role);

		} else {
			$wp_role = $xenword_options['wp_default_role'];
		}

		XenWord_XF_Users::add_user( $wp_role );

	}

	public static function add_user( $wp_role ) {

		global $wpdb;

		$visitor = XenWord::getVisitor();
		$xenword_options = get_option( 'xenword_options' );

		$user_id = $visitor['user_id'];

		$user_check           = $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->users} WHERE ID = '$user_id' " );
		$user_id              = $visitor['user_id'];
		$password             = wp_generate_password();
		$nickname             = $visitor['username'];
		$email                = $visitor['email'];
		$current_registration = date( 'Y/m/d H:i:s', $visitor['register_date'] );

		if ( null == username_exists( $email ) ) {

			/**
			 * usermeta -> first_name, last_name, nickname,
			 * description, rich_editing, comment_shortcuts,
			 * admin_color, use_ssl, show_admin_bar_front
			 */

			$new_userdata = array(
				'ID'              => $user_id,
				'user_login'      => $nickname,
				'user_pass'       => $password,
				'user_nicename'   => $nickname,
				'user_email'      => $email,
				'user_registered' => $current_registration,
				'display_name'    => $nickname
			);

			if ( $user_check == 1 ) {

				/**
				 * wp_update_user resets cookies leading to a nonce error in the WP admin panel.
				 */

				// Check if admin
				if ( ! current_user_can( 'manage_options' ) ) {

					// Check if no secondary user group
					if ( null == $wp_role  && $visitor['is_banned'] != 1 ) {
						$wp_role = $xenword_options['wp_default_role'];
					}

					// Set the role
					$user = new WP_User( $user_id );
					$user->set_role( $wp_role );
				}

				// Check role is_baned
				if ( $visitor['is_banned'] == 1 ) {

					// Remove any roles
					remove_role( $wp_role );

				}


			} else {

				// Insert userdata into prefix_users table
				$table = $wpdb->prefix . 'users';
				$wpdb->insert( $table, $new_userdata );

				if ( null == $wp_role ) {
					$wp_role = $xenword_options['wp_default_role'];
				}

				// Set the role
				$user = new WP_User( $user_id );
				$user->set_role( $wp_role );

				if ( $xenword_options['use_wordpress_toolbar'] == true ) {
					update_user_meta( $user_id, 'show_admin_bar_front', 'true' );
				} else {
					update_user_meta( $user_id, 'show_admin_bar_front', 'false' );
				}
			}
		}
	}
}

new XenWord_XF_Users();

// End class-xenword-add-wpusers.php