<?php

/**
 * Filename: class-xenword-avatars.php
 *
 * XenForo handles avatars
 *
 * @package    XenWord
 * @subpackage WordPress/includes
 *
 * @since WordPress 4.4 the handling of Avatars has been changed
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWord_Avatars {

	public function __construct() {
		$this->hooks();
	}

	public function hooks() {
		add_filter( 'get_avatar', array( $this, 'set_avatar' ), 10, 6 );
		add_filter( 'avatar_defaults', array( $this, 'xenword_avatar_defaults' ) );
	}

	public function set_avatar( $avatar, $id_or_email, $size = '96', $default = '', $alt = false, $args  ) {

		if ( ! get_option( 'show_avatars' ) ) {
			return false;
		}

		// Properly show Avatars and Gravatars on the options-discussion.php page
		if ( is_admin() ) {
			$screen = get_current_screen();
			if ( is_object($screen) && in_array( $screen->id, array( 'dashboard', 'options-discussion' ) ) && ( $default != 'XenForo' ) ) {
				return $avatar;
			}
		}

		if ( false === $alt ) {
			$safe_alt = '';
		} else {
			$safe_alt = esc_attr( $alt );
		}

		if ( ! is_numeric( $size ) ) {
			$size = '96';
		}

		if ( is_numeric( $id_or_email ) ) {
			$id   = (int) $id_or_email;

		} elseif ( is_object( $id_or_email ) ) {

			// No avatar for pingbacks or trackbacks
			$allowed_comment_types = apply_filters( 'get_avatar_comment_types', array( 'comment' ) );

			if ( ! empty( $id_or_email->comment_type ) && ! in_array( $id_or_email->comment_type, (array) $allowed_comment_types ) ) {
				return false;
			}

			if ( ! empty( $id_or_email->user_id ) ) {
				$id   = (int) $id_or_email->user_id;

			} elseif ( ! empty( $id_or_email->comment_author_email ) ) {
				$email = $id_or_email->comment_author_email;
				/**
				 * Added to grab XenForo userInfo for author box
				 *
				 * @var $userModel XenForo_Model_User
				 */
				$userModel = XenForo_Model::create( 'XenForo_Model_User' );
				$userinfo = $userModel->getUserByEmail( $email );
				$id = $userinfo['user_id'];
			}

		} else {
			$email = $id_or_email;

			/**
			 * Added to grab XenForo userInfo for author box
			 *
			 * @var $userModel XenForo_Model_User
			 */
			$userModel = XenForo_Model::create( 'XenForo_Model_User' );
			$userinfo = $userModel->getUserByEmail( $email );
			$id = $userinfo['user_id'];

		}

		/** @var  $userModel XenForo_Model_User */
		$userModel = XenForo_Model::create('XenForo_Model_User');
		$userinfo = $userModel->getFullUserById( $id );

		$gravatar = $userinfo['gravatar'];

		$xf_avatar_url = XenForo_Template_Helper_Core::helperAvatarUrl( $userinfo, 'm' , false );

		// Check if it is a Gravatar
		if ( $gravatar === '' ) {

			// No gravatar
			$out = XenWord::getBoardUrl() . '/' . $xf_avatar_url;

		} else {
			$out = $xf_avatar_url;
		}

		$avatar = "<img alt='{$safe_alt}' src='{$out}' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
		return $avatar;
	}

	/**
	 * Add Custom Avatar (Discussion Settings)
	 *
	 * @param $avatar_defaults
	 *
	 * @return mixed @throws Zend_Exception
	 */

	public function xenword_avatar_defaults( $avatar_defaults ) {

		// Get Avatar from plugin folder
		$new_avatar = plugins_url( '../admin/images/xenforo_logo.og.png', __FILE__ );
		$avatar_defaults[$new_avatar] = "XenForo";

		// Remove default avatars
		//unset ( $avatar_defaults['mystery'] );
		//unset ( $avatar_defaults['blank'] );
		//unset ( $avatar_defaults['gravatar_default'] );
		//unset ( $avatar_defaults['identicon'] );
		//unset ( $avatar_defaults['wavatar'] );
		//unset ( $avatar_defaults['monsterid'] );
		//unset ( $avatar_defaults['retro'] );
		return $avatar_defaults;
	}
}

new XenWord_Avatars();

// End class-xenword-avatars.php