<?php

/**
 * Filename: xenword-comments.php
 * Description: XenForo handles comments, replace BBCode with HTML
 *
 * @author      LPH
 * @version     2.5.1.01
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 1.0.0.1
 *        Initial release
 * @since 2.5.1.01
 *        Replaced global $xenword_options with get_option
 * @since 2.5.1.03
 *        Bug Fix in create XenForo_Model_Forum
 *        Bug Fix SQL in xf_set_post_id
 * @since 2.5.1.04
 *        Added er_what BBCode
 *        Change query to use prepare
 * @deprecated  3.0.0
 *
 * @TODO Use wp_new_comment to write the XenForo thread ID reply to the WordPress comments table.
 *
 */

defined( 'ABSPATH' ) OR exit;


/**
 * xf_load_comments
 *
 * @param $comment
 * @param $post_id
 *
 * @return array|string
 * @throws Zend_Exception
 */
function xf_load_comments( $comment, $post_id ) {
	global $XF, $wp_query, $xf_comments;

	/**
	 * Loads the XenWord options saved in the XenWord panel.
	 * @var  $xenword_options
	 */
	$xenword_options = get_option( 'xenword_options' );

	$wp_query->set( 'comments_per_page', $xenword_options['comments_per_page'] );

	if ( XenWord_Comments::useXenForoCommentHandler() ) {
		$XF->post = get_post( $post_id );

		/** Are we displaying comments in WP? */
		if ( $xenword_options['display_comments_in_wp'] == true ) {
			// $formatter = XenForo_BbCode_Formatter_Base::create();
			$parser = new XenForo_BbCode_Parser( new XenForo_BbCode_Formatter_Wysiwyg );

			// $bbCodeParser = new XenForo_BbCode_Parser(new XenForo_BbCode_Formatter_Wysiwyg);

			$comments = $xf_comments->getCommentsFromCache( $post_id );

			/**  load timezone related options */
			$gmt_offset  = (float) get_option( 'gmt_offset' ) * 3600;

			// The earliest XF comment
			$earliest_timestamp = 999999999999999;

			$mycomments = '';

			if ( isset( $mycomments ) ) {

				$i = - 1;
				foreach ( $comments as $mycomment ) {
					if ( $i != - 1 ) {
						$mycomments[ $i ]                       = new StdClass;
						$mycomments[ $i ]->comment_ID           = (string) $mycomment['post_id'];
						$mycomments[ $i ]->comment_post_ID      = (string) $post_id;
						$mycomments[ $i ]->comment_author       = $mycomment['username'];
						$mycomments[ $i ]->comment_author_email = $mycomment['email'];

						if ( $mycomment['user_id'] != '0' ) {
							$mycomments[ $i ]->comment_author_url = XenForo_Link::buildPublicLink( 'canonical:members/' . strtolower( $mycomment['username'] ) . '.' . $mycomment['user_id'] . '/' );
						} else {
							$mycomments[ $i ]->comment_author_url = '';
						}

						$mycomments[ $i ]->comment_date     = gmdate( 'Y-m-d H:i:s', $mycomment['post_date'] + $gmt_offset );
						$mycomments[ $i ]->comment_date_gmt = gmdate( 'Y-m-d H:i:s', $mycomment['post_date'] );
						$mycomments[ $i ]->comment_content  = $parser->render( $mycomment['message'] );

						$mycomments[ $i ]->comment_content = str_replace("styles", XenWord::getBoardUrl() . "/styles", $mycomments[ $i ]->comment_content);

						$mycomments[ $i ]->comment_karma    = $mycomment['likes'];
						$mycomments[ $i ]->comment_approved = '1';
						$mycomments[ $i ]->comment_type     = '';
						$mycomments[ $i ]->comment_parent   = '0';
						$mycomments[ $i ]->user_id          = $mycomment['user_id'];
						$mycomments[ $i ]->timestamp        = strtotime( $mycomments[ $i ]->comment_date_gmt );

						if ( $mycomments[ $i ]->timestamp < $earliest_timestamp ) {
							$earliest_timestamp = $mycomments[ $i ]->timestamp;
						}
					}
					$i ++;
				}
			}

			/**
			 * We now have our complete comment array,
			 * but what about comments that haven't made it to XenForo (old comments etc)
			 * $comments_to_merge = array();
			 */
			 foreach ( $comment as $this_comment ) {

				 /**
				 * Conditional to test if comment has a corresponding post_id in xf_post table
				 */

				if ( ! isset( $this_comment->XF_post_ID ) || $this_comment->XF_post_ID == '0' ) {

					// var_dump($this_comment);

					// Requires that the comment was made before XF took over.
					//if ( strtotime( $this_comment->comment_date_gmt < $earliest_timestamp ) ) {

						$comments_to_merge[] = $this_comment;
					//}
				}
			}

			/** Check if we found any comments we need to merge, and if so merge then sort them */

			/** @var $comments_to_merge */
			if ( $comments_to_merge != array() ) {

				if ( is_array( $mycomments ) ) {
					$mycomments = array_merge( $mycomments, $comments_to_merge );
				} else {
					$mycomments = $comments_to_merge;
				}

				foreach ( $mycomments as $mycomment ) {

					if ( ! isset( $mycomment->timestamp ) ) {
						$mycomment->timestamp = strtotime( $mycomment->comment_date_gmt );
					}
				}
				usort( $mycomments, 'xf_usort_compare_comment_time' );
			}

			/**
			 * Add it to $wp_query so basic wp functions will use the correct comment array,
			 * set up pagination stuff
			 */
			$wp_query->comments = $mycomments;

			return $mycomments;
		} else {

			/**  We are just displaying a link to the XF thread */
			return array();
		}
	} else {
		return $comment;
	}
}

add_filter( 'comments_array', 'xf_load_comments', 10, 2 );


/**
 * usort callback function (see above)
 *
 * @param $comment1
 * @param $comment2
 *
 * @return number
 */
function xf_usort_compare_comment_time( $comment1, $comment2 ) {
	$time1 = $comment1->timestamp;
	$time2 = $comment2->timestamp;

	if ( $time1 == $time2 ) {
		return 0;
	}

	return ( $time1 > $time2 ) ? 1 : - 1;
}


/**
 * @param $comment
 *
 * @return mixed
 * @throws Exception
 * @throws XenForo_Exception
 */
function xf_save_comment( $comment ) {
	global $XF;

	if ( XenWord_Comments::useXenForoCommentHandler( $comment ) ) {
		$thread_id = XenWord::getThreadIdForPost( $comment['comment_post_ID'] );

		//$formatter = XenForo_BbCode_Formatter_Base::create();
		//$parser = new XenForo_BbCode_Parser( $formatter );

		$parser = new XenForo_BbCode_Parser(new XenForo_BbCode_Formatter_Wysiwyg);

		$visitor = XenWord::getVisitor();

		if ( $thread_id !== false && $thread_id !== null && $visitor['is_banned'] != true ) {

			/** @var  $threadModel XenForo_Model_Thread*/
			$threadModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache( 'XenForo_Model_Thread' );

			/** @var  $forumModel XenForo_Model_Forum */
			$forumModel  = XenForo_Model::create('XenForo_Model_Forum')->getModelFromCache('XenForo_Model_Forum');
			$thread      = $threadModel->getThreadById( $thread_id );
			$forum       = $forumModel->getForumById( $thread['node_id'] );

			$errorPhraseKey = '';
			if ( $threadModel->canReplyToThread( $thread, $forum, $errorPhraseKey ) ) {

				if ( ! $visitor->hasPermission( 'general', 'bypassFloodCheck' ) ) {
					$floodTimeRemaining = XenForo_Model_FloodCheck::checkFlooding( 'post', null );

					if ( $floodTimeRemaining ) {
						wp_die( 'Пользователь наводнения. Не удается обработать комментарий' );
					}
				}

				$user_id = $visitor['user_id'];

				$writer = XenForo_DataWriter::create( 'XenForo_DataWriter_DiscussionMessage_Post' );
				$writer->set( 'user_id', $user_id );
				$writer->set( 'username', $visitor['username'] );

				$new_wordpress_comment_content = $parser->render( $comment['comment_content'] ); //convert the BBCode they typed to HTML

				if ( $comment['comment_parent'] != '0' ) { //Handle automatically adding quotes for replies

					/** @var  $postModel XenForo_Model_Post */
					$postModel = XenForo_Model::create('XenForo_Model_Post')->getModelFromCache( 'XenForo_Model_Post' );
					$post = $postModel->getPostById( $comment['comment_parent'] );
					$comment['comment_content'] = '[quote="'
					                              . $post['username']
					                              . ', post: '
					                              . $comment['comment_parent']
					                              . '"]'
					                              . $post['message']
					                              . '[/quote]'
					                              . $comment['comment_content'];
				}

				$writer->set( 'message', stripslashes( $comment['comment_content'] ) );
				$comment['comment_content'] = $new_wordpress_comment_content;

				/** @var  $postModel XenForo_Model_Post */
				$postModel = XenForo_Model::create('XenForo_Model_Post')->getModelFromCache( 'XenForo_Model_Post' );
				$writer->set( 'message_state', $postModel->getPostInsertMessageState( $thread, $forum ) );
				$writer->set( 'thread_id', $thread_id );

				/**
				 * Guest Post
				 */
				if ( $user_id == 0 ) {
					$writer->set( 'username', $comment['comment_author'] );
				}

				$writer->setExtraData( XenForo_DataWriter_DiscussionMessage::DATA_ATTACHMENT_HASH, '' );
				$writer->preSave();

				if ( ! $writer->hasErrors() ) {
					$writer->save();
					$XF->insertion_id = $writer->get( 'post_id', 'xf_post' );
				} else {
					$errors = $writer->getErrors();

					//Guest post with non-unique username
					if ( isset( $errors['username'] ) && $user_id == 0 ) {
						$i = 2;

						while ( true ) {
							//Try again to see if we can produce a unique username for the guest to use [they hopefully don't care too much about their display name]
							$writer = XenForo_DataWriter::create( 'XenForo_DataWriter_DiscussionMessage_Post' );
							$writer->set( 'user_id', $user_id );
							$writer->set( 'message', stripslashes( $comment['comment_content'] ) );

							if ( $i == 2 ) {
								$writer->set( 'username', $comment['comment_author'] . " comments" );
							} else {
								$writer->set( 'username', $comment['comment_author'] . $i );
							}

							/** @var  $postModel XenForo_Model_Post */
							$postModel = XenForo_Model::create('XenForo_Model_Post');

							$writer->set( 'message_state', $postModel->getPostInsertMessageState( $thread, $forum ) );
							$writer->set( 'thread_id', $thread_id );
							$writer->setExtraData( XenForo_DataWriter_DiscussionMessage::DATA_ATTACHMENT_HASH, '' );
							$writer->preSave();

							if ( ! $writer->hasErrors() ) {
								$writer->save();
								break;
							} else {
								$errors = $writer->getErrors();

								if ( isset( $errors['username'] ) ) {
									$i ++;
									continue;
								}
							}
						}
					}
				}
			}
		}
	}

	return $comment;
}

add_filter( 'preprocess_comment', 'xf_save_comment' );


/**
 * Function xf_set_post_id
 * Writes the comment_id to XF_post_ID in wp_comments table
 *
 * @param $comment_id
 *
 * @since 1.0.0.1
 *        Initial release
 * @since 2.5.1.04
 *        Change query to use prepare
 *
 */
function xf_set_post_id( $comment_id ) {
	global $XF, $wpdb;

	if ( isset( $XF->insertion_id ) ) {
		$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->comments} SET XF_post_ID =%d WHERE comment_ID = %d", $XF->insertion_id, $comment_id) );
	}
}

add_action( 'comment_post', 'xf_set_post_id' );


/**
 * xf_comment_post_redirect
 *
 * @param $redirect
 * @param $post
 *
 * @return mixed
 * @throws XenForo_Exception
 */
function xf_comment_post_redirect( $redirect, $post ) {
	global $XF;

	if ( XenWord_Comments::useXenForoCommentHandler( $post ) ) {
		global $wp_query;

		$thread_id    = XenWord::getThreadIdForPost( $post->comment_post_ID );

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel  = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache( 'XenForo_Model_Thread' );
		$thread       = $threadModel->getThreadById( $thread_id );
		$num_comments = $thread['reply_count'];

		$wp_query->set( 'comments_per_page', $XF->options['comments_per_page'] );
		$pages = ceil( $num_comments / $wp_query->get( 'comments_per_page' ) );

		if ( strpos( $redirect, '?' ) !== false ) {
			$redirect = str_replace( '#comment-' . $post->comment_ID, '&cpage=' . $pages . '#comment-' . $XF->insertion_id, $redirect );
		} else {
			$redirect = str_replace( '#comment-' . $post->comment_ID, '?cpage=' . $pages . '#comment-' . $XF->insertion_id, $redirect );
		}

		return $redirect;
	}

	return $redirect;
}

add_filter( 'comment_post_redirect', 'xf_comment_post_redirect', 10, 2 );


/**
 * @param $open
 *
 * @return bool
 * @throws XenForo_Exception
 */
function xf_comments_open( $open ) {

	/**
	 * Loads the XenWord options saved in the XenWord panel.
	 *
	 * @var  $xenword_options
	 */
	$xenword_options = get_option( 'xenword_options' );
	$visitor = XenWord::getVisitor();

	if ( XenWord_Comments::useXenForoCommentHandler() ) {
		//check if we are display comments in WordPress
		if ( $xenword_options['display_comments_in_wp'] == true ) {

			if ( isset( $comment ) ) {

				/**
				 * comment_post_ID from wp_comments matches ID in wp_posts
				 *
				 * @var  $thread_id
				 */
				$thread_id = XenWord::getThreadIdForPost( $comment['comment_post_ID'] );
			}

			if ( isset( $thread_id ) ) {
				if ( $thread_id !== false && $thread_id !== null ) {

					/** @var  $threadModel XenForo_Model_Thread */
					$threadModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache( 'XenForo_Model_Thread' );

					/** @var  $forumModel XenForo_Model_Forum */
					$forumModel  = XenForo_Model::create('XenForo_Model_Forum')->getModelFromCache( 'XenForo_Model_Forum' );
					$thread      = $threadModel->getThreadById( $thread_id );
					$forum       = $forumModel->getForumById( $thread['node_id'] );

					$errorPhraseKey = '';
					if ( $threadModel->canReplyToThread( $thread, $forum, $errorPhraseKey ) && $visitor['is_banned'] != true ) {
						return true;
					} elseif ( $visitor['user_id'] != '0' ) {
						return false;
					}
				}
			}

			return true;
		} else {
			/**
			 * we are only displaying a link to the XF thread
			 */

			return false;
		}
	} else {
		return $open;
	}
}

add_filter( 'comments_open', 'xf_comments_open', 10, 2 );

/**
 * @param $value
 *
 * @return bool
 * @throws XenForo_Exception
 */
function xf_check_comment_must_login( $value ) {
	global $wp_query;

	if ( XenWord_Comments::useXenForoCommentHandler() ) {
		$thread_id = XenWord::getThreadIdForPost( $wp_query->query_vars['p'] );

		// var_dump($wp_query->query_vars);

		if ( $thread_id !== false && $thread_id !== null ) {

			/** @var  $threadModel XenForo_Model_Thread */
			$threadModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache('XenForo_Model_Thread');

			/** @var  $forumModel XenForo_Model_Forum */
			$forumModel  = XenForo_Model::create('XenForo_Model_Forum')->getModelFromCache('XenForo_Model_Forum');
			$thread      = $threadModel->getThreadById( $thread_id );
			$forum       = $forumModel->getForumById( $thread['node_id'] );
			$errorPhraseKey = '';

			if ( $threadModel->canReplyToThread( $thread, $forum, $errorPhraseKey ) ) {
				return false;
			} else {
				return true;
			}
		}

		return false;
	}

	return $value;
}

add_filter( 'option_comment_registration', 'xf_check_comment_must_login' );

/**
 * xf_page_comments
 *
 * @param $value
 *
 * @return bool
 */
function xf_page_comments( $value ) {

	if ( XenWord_Comments::useXenForoCommentHandler() ) {
		return true;
	}

	return $value;
}

add_filter( 'pre_option_page_comments', 'xf_page_comments' );


/**
 * xf_default_comments_page
 * @param $value
 *
 * @return string
 */
function xf_default_comments_page( $value ) {

	/**
	 * Loads the XenWord options saved in the XenWord panel.
	 * @var  $xenword_options
	 */
	$xenword_options = get_option( 'xenword_options' );

	if ( XenWord_Comments::useXenForoCommentHandler() ) {

		if ( $xenword_options['use_comment_order'] == 'older' ) {

			return 'oldest';

		} else {

			return 'newest';
		}
	}

	return $value;
}

add_filter( 'pre_option_default_comments_page', 'xf_default_comments_page' );

/**
 * Removes the edit link in the WP theme. All comment editing should be done in XenForo.
 *
 * @return string
 */
function xenword_remove_edit_post_link() {
	return '';
}

add_filter('edit_comment_link', 'xenword_remove_edit_post_link');


/**
 * Replaces BBCode tags as HTML
 *
 * @param $content
 *
 * @return mixed
 * @throws Zend_Exception
 *
 * @since 2.5.0.05
 *        Replaced the /e modifier
 * @since 2.5.1.01
 *        Added BBCode for user, spoiler, YouTube media
 * @since 2.5.1.04
 *        Added er_what BBCode
 */
function embed_BBCode($content) {

	$content = preg_replace('~\[img\](.+?)\[\/img\]~i', '<img src=\"$1\" alt=\"" . basename("$1") . "\" />', $content);

	$content = preg_replace('~\[user=(.*?)\](.*?)\[/user\]~i', '<a href=' . XenWord::getBoardUrl() . '/members/$1>' . '$2</a>', $content);

	$content = preg_replace('~\[/user\]~i', '', $content);

	$content = preg_replace('~\[attach=.*?\](.*?)\[/attach\](?!\[/attach\])~i', '<img src=' . XenWord::getBoardUrl() . '/attachments/$1 />', $content);

	$content = preg_replace('~\[/attach\]~i', '', $content);

	$content = preg_replace('~\[media=(.*?)\](.*?)\[/media\](?!\[/media\])~i', '<embed src="http://www.youtube.com/v/$2" width="415" height="250"></embed>', $content);

	$content = preg_replace('~\[/media\]~i', '', $content);

	$content = preg_replace('~\[b\](.+?)\[\/b\]~i', '<strong>$1</strong>', $content);

	$content = preg_replace('~\[i\](.+?)\[\/i\]~i', '<em>$1</em>', $content);

	$content = preg_replace('~\[code\](.+?)\[\/code\]~i', '<code>$1</code>', $content);

	$content = preg_replace('~\[php\](.+?)\[\/php\]~i', '<pre>$1</pre>', $content);

	$content = preg_replace('~\[quote\]~siU', '<blockquote>', $content);

	$content = preg_replace('~\[quote=(.*)\]~siU', '<blockquote>', $content);

	$content = preg_replace('~\[/quote\]~siU', '</blockquote>', $content);

	$content = preg_replace('~\[spoiler\](.*?)\[/spoiler\](?!\[/spoiler\])~i', '<strong>СПОЙЛЕР</strong><br />$1<br /><br />', $content);

	$content = preg_replace('~\[spoiler=(.*?)\](.*?)\[/spoiler\](?!\[/spoiler\])~i', '<strong>СПОЙЛЕР</strong><br />$2<br /><br />', $content);

	$content = preg_replace('~\[/spoiler\]~i', '', $content);

	$content = preg_replace('~\:confused\:~i', ':???:', $content);

	$content = preg_replace('~\:rolleyes\:~i', ':roll:', $content);

	$content = preg_replace('~\:p~i', ':razz:', $content);

	$content = preg_replace('~o_O~i', ':?:', $content);

	return $content;
}

add_filter('comment_text', 'embed_BBCode');

/**
 * Use wp_new_comment() to write to the comment database.
 *
 * http://codex.wordpress.org/Function_Reference/wp_new_comment
 *
 * https://github.com/WordPress/WordPress/blob/master/wp-comments-post.php
 *
$commentdata = compact('comment_post_ID', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type', 'comment_parent', 'user_ID');
$comment_id = wp_new_comment( $commentdata );
if ( ! $comment_id ) {
	wp_die( __( "<strong>ERROR</strong>: The comment could not be saved. Please try again later." ) );
}
$comment = get_comment( $comment_id );

*/

// End of xenword-comments.php