<?php

/**
 * Filename: class-xenword-footer.php
 *
 * Description: XenWord Branding File for the WordPress footer
 *
 * Shows a link to www.xenword.com unless the option to remove the branding link is switched to true.
 * This file is called from the class-xenword-loader.php.
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 1.0.0.4
 *        Initial release
 * @since 1.0.0.5
 *        Enabled the link by default
 * @since 2.5.1.01
 *        Cleaned up the DocBlocks
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

Class XenWord_Footer {

	public function __construct() {

		/**
		 * A hook to the wp_footer function
		 * Return: (bool) Will always return true.
		 */
		add_action( 'wp_footer', array( &$this, 'footer' ) );
	}

	function footer() {

		/**
		 * Loads the XenWord options saved in the XenWord panel.
		 * @var  $xenword_options
		 */
		$xenword_options = get_option( 'xenword_options' );

		/**
		 * Shows the branding link to XenWord.com
		 * This option is toggled 'on' or 'off' in the XenWord settings panel for XenWord
		 *
		 * 'on' == true
		 * 'off' == false
		 *
		 */
		if ( $xenword_options['remove_branding'] == false ) {
			echo '<div class="xenword_branding">';
			echo $xenword_options['xenword_footer_text'];
			echo '</div>';
		}
	}
}

new XenWord_Footer();

// End of xenword-footer.php