<?php

/**
 * Filename: class-xenword-includes.php
 *
 * Contains the required files if XenWord is activated.
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes
 **
 * @since 2.2.0.02
 *        Initial file
 *
 * @since 3.0.2.01
 *        Arranged requires in order of file names for easier identification
 *
 * @TODO get file names and class names organized for autoload
 */



/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWord_Includes {

	public function __construct() {
		$this->includes();
	}

	public static function includes() {

		/** Load the XenWord options set in XenWord settings panel */
		$xenword_options = get_option( 'xenword_options' );

		/** Load the XenWord file to add XF members to WordPress. */
		require_once( 'class-xenword-add-wpusers.php' );

		/** Load the author link file */
		if ( $xenword_options['use_author_link'] == true ) {
			require_once( 'class-xenword-author-link.php' );
		}

		if ( $xenword_options['xf_sync_avatars'] == true ) {
			require_once( 'class-xenword-avatars.php' );
		}

		require_once( 'class-xenword-cookies.php' );

		/** Load the XenWord file to login XF members into WordPress. */
		if ( $xenword_options['wp_version_45'] == true ) {
			require_once( 'class-xenword-login-xfusers-4.5.php' );
		} else {
			require_once( 'class-xenword-login-xfusers-4.4.php' );
		}

		require_once( 'class-xenword-login-wpusers.php' );

		/** Load the post ratings file */
		if ( $xenword_options['use_postratings'] == true ) {
			require_once( 'addons/class-xenword-postratings.php' );
		}

		require_once( 'class-xenword-redirects.php' );

		require_once( 'class-xenword-shortcodes.php' );

		/** Load the XenWord public css. */
		require_once( 'class-xenword-stylesheets.php' );

		if ( $xenword_options['use_thread_creation'] == true ) {

			/** Load the XenWord thread creation file */
			require_once( 'class-xenword-thread-creation.php' );

			/** Load XenWord Thread Link */
			require_once( 'class-xenword-thread-link.php' );

			/** Load the class XenWord_AddThreadID to admin edit.php page */
			require_once ( plugin_dir_path( dirname( __FILE__ ) )  . 'admin/includes/class-xenword-add-threadid.php' );

			/** Load the XenWord Thread ID meta box. */
			require_once( 'class-xenword-metabox-threadid.php' );

			if ( $xenword_options['use_default_forum'] == false ) {
				/** Load the XenWord Forum ID meta box. */
				require_once( 'class-xenword-metabox-forumid.php' );
			}

			if ( $xenword_options['use_resource_creation'] == true ) {

				/** Load the XenWord resource creation file */
				require_once( 'addons/class-xenword-resource-creation.php' );

				/** Load the XenWord resource ID meta box. */
				require_once( 'addons/class-xenword-metabox-resourceid.php' );

				/** Load the XenWord resource category meta box. */
				require_once( 'addons/class-xenword-metabox-resource-category.php' );
			}
		}

		/** Load the XenWord toolbar for alerts, conversations. */
		require_once( 'class-xenword-toolbar.php' );

		/** Load the XenWord toolbar login - signup links */
		require_once( 'class-xenword-toolbar-login.php' );

		require_once( 'class-xenword-users-admin.php' );

		require_once( 'class-xenword-users-data.php' );

		/** Load the comment system file */
		if ( $xenword_options['use_comment_system'] == true ) {
			require_once( 'class-xenword-wordpress-comments.php' );
		}

	}
}

new XenWord_Includes();

// End class-xenword-includes.php