<?php

/**
 * Filename: class-xenword-loader.php
 *
 * Description: This file loads the constants, basic includes before settings, widgets, and admin files.
 *
 * @author      LPH
 * @version     2.5.1.01
 * @package     XenWord
 * @subpackage  WordPress/includes
 *
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWord_Loader {

	/**
	 * PHP5 constructor method.
	 *
	 * @since XenWord 1.0.0
	 */
	public function __construct() {

		/** Set the constants needed by the plugin. */
		add_action( 'plugins_loaded', array( &$this, 'constants' ), 1 );

		/** Internationalize the text strings used. */
		add_action( 'plugins_loaded', array( $this, 'languages' ), 2 );

		/** Load the functions files. */
		add_action( 'plugins_loaded', array( &$this, 'includes' ), 3 );

		/** Load the widget files. */
		add_action( 'plugins_loaded', array( &$this, 'widgets' ), 4 );

		/** Load the admin files. */
		add_action( 'plugins_loaded', array( &$this, 'admin' ), 5 );

	}

	/**
	 * Defines constants used by the XenWord plugin.
	 *
	 * @since XenWord 1.0.0
	 */
	public function constants() {

		/** Set the version number of the plugin. */
		define( 'XENWORD_VERSION', '3.0.2.03' );

		/** Set the version description of the plugin. */
		define( 'XENWORD_RELEASE', 'Alpha Release' );

		/** Set the database version number of the plugin. */
		define( 'XENWORD_DB_VERSION', 3 );

		/** Set constant path to the XenWord plugin directory. */
		define( 'XENWORD_DIR', trailingslashit( plugin_dir_path( __FILE__ ) ) );

		/** Set constant path to the XenWord plugin URL. */
		define( 'XENWORD_URI', trailingslashit( plugin_dir_url( __FILE__ ) ) );

		/** Set the constant path to the XenWord includes directory. */
		define( 'XENWORD_INCLUDES', XENWORD_DIR . trailingslashit( '' ) );

		/** Set the constant path to the XenWord widgets directory. */
		define( 'XENWORD_WIDGETS', XENWORD_DIR . trailingslashit( 'widgets' ) );

		/** Set the constant path to the XenWord admin directory. */
		define( 'XENWORD_ADMIN', XENWORD_DIR . trailingslashit( '../admin' ) );

		/** Set the constant path to the XenWord languages directory. */
		define( 'XENWORD_LANG', XENWORD_DIR . trailingslashit( '../languages' ) );

	}

	/**
	 * Loads the plugin text domain for translation.
	 *
	 * @since       1.0.3.01
	 * @since       2.4.1.06
	 */
	public static function languages() {

		load_plugin_textdomain( 'xenword', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

	}

	/**
	 * Loads the initial files needed by the plugin.
	 *
	 * @since XenWord 1.0.0
	 */
	public function includes() {

		/** Load the XenWord branding system file. */
		require_once( XENWORD_INCLUDES . 'class-xenword-footer.php' );

		/** Load the XenWord export WordPress users system file. */
		require_once( XENWORD_INCLUDES . 'class-xenword-export-users.php' );

	}

	/**
	 * Loads the optional widget files.
	 *
	 * @since 1.0.1.03
	 * @since 2.5.0.05
	 *        Load the xenproduct widget
	 */
	public function widgets() {

		/** Load the XenReviews Items Widget file. */
		require_once( XENWORD_WIDGETS . 'xenword-dashboard-widget.php' );

		/** Load the XenWord widget board totals file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-boardtotals-widget.php' );

		/** Load the XenWord widget Latest Thread from All Forums file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-forum-by-category-widget.php' );

		/** Load the XenWord widget Feature Forum file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-forum-feature-widget.php' );

		/** Load the XenWord widget Feature Forum file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-forum-feature-version-2-widget.php' );

		/** Load the XenWord widget XF Login file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-login-widget.php' );

		/** Load the XenWord widget XF Login Horizontal file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-login-horizontal-widget.php' );

		/** Load the XenWord widget XF Notice file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-notice-widget.php' );

		/** Load the XenWord widget online users file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-onlineusers-widget.php' );

		/** Load the XenWord widget XF Resource Information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-resource-widget.php' );

		/** Load the XenWord widget XenProduct Items file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-xenproduct-widget.php' );

		/** Load the XenWord widget Showcase Items file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-showcase-items-widget.php' );

		/** Load the XenWord widget Latest Thread from All Forums file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-thread-all-forums-widget.php' );

		/** Load the XenWord widget Latest Thread By Forum Information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-thread-by-forum-widget.php' );

		/** Load the XenWord widget Feature Thread Information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-thread-feature-widget.php' );

		/** Load the XenWord widget Popular Thread Information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-thread-popular-widget.php' );

		/** Load the XenWord widget Latest Thread By Forum Information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-thread-replies-widget.php' );

		/** Load the XenWord widget current user information file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-user-info-widget.php' );

		/** Load the XenReviews Widget file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-xenreviews-widget.php' );

		/** Load the XenReviews Items Widget file. */
		require_once( XENWORD_WIDGETS . 'xenword-xf-xenreviews-items-widget.php' );


	}

	/**
	 * Loads the admin function, contains the conditional to load only if in WP admin panel
	 */
	public function admin() {

		/**
		 *  Load admin options only if user has admin permissions
		 */

		if ( is_admin() ) {

			/** Add Redux Framework & extras */
			require_once ( XENWORD_ADMIN  . 'admin-init.php' );
		}
	}
}

new XenWord_Loader();

// End class-xenword-loader.php