<?php

/**
 * Filename: class-xenword-metabox-forumid.php
 *
 * Loads the forum information in the WordPress post panel via a metabox.
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes
 *
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Add the meta box to the post page
 * Located in the side.
 */
function add_xenforo_forum_id_meta_box() {

	$post_types = get_post_types();

	foreach ( $post_types as $post_type ) {

		add_meta_box(
			'xenforo_forum_id_meta_box',
			__( 'XenForo Форумы', 'xenword' ),
			'show_forum_id_meta_box',
			$post_type,
			'side', // $context
			'high'  // $priority
		);
	}
}

add_action( 'add_meta_boxes', 'add_xenforo_forum_id_meta_box' );

/**
 * Prints the box content.
 *
 * @since 2.2.0.1
 *
 * @param $post
 *
 * @throws XenForo_Exception
 */
function show_forum_id_meta_box( $post ) {

	// Add an nonce field so we can check for it later.
	wp_nonce_field( 'xenword_meta_forum_id_box', 'xenword_meta_box_forum_id_nonce' );

	$forumId = XenWord::getForumIdForPost($post->ID);

	/** @var  $forumModel XenForo_Model_Node */
	$forumModel = XenForo_Model_Node::create( 'XenForo_Model_Node' );
	$forums = $forumModel->getViewableNodeList( null, true );

	echo '<select id="xenword_forum_id" name="xenword_forum_id" class="textCtrl" >';

	foreach ( $forums as $forum ) {

		if ( $forum['node_type_id'] == 'Forum' ) {

			echo '<option value="' . $forum['node_id'] . '"';

			if ( $forum['node_id'] == $forumId ) {
				echo 'selected="selected"';
			}

			echo ' class="_depth' . $forum['depth'] . '">' . $forum['title'] . '</option>';

		}
	}

	echo '</select>';
}

/**
 * Custom data is saved when the post is saved.
 *
 * @since 2.0.1.1
 *
 * @param int $post_id The ID of the post being saved.
 */
function xenword_save_meta_box_forum_id_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['xenword_meta_box_forum_id_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['xenword_meta_box_forum_id_nonce'], 'xenword_meta_forum_id_box' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */

	// Make sure that it is set.
	if ( ! isset( $_POST['xenword_forum_id'] ) ) {
		return;
	}

	// Sanitize user input.
	$thread_data = sanitize_text_field( $_POST['xenword_forum_id'] );

	// Update the meta field in the database.
	update_post_meta( $post_id, 'forum_id', $thread_data );

}

add_action( 'pre_post_update', 'xenword_save_meta_box_forum_id_data', 10, 2 );

// End class-xenword-metabox-forumid.php