<?php

/**
 * Filename: class-xenword-redirects.php
 *
 * Completes the login redirects
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 2.1.0.3
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWord_Redirects {

	public function __construct() {

		add_filter( 'login_url', array( &$this, 'xf_login_redirect' ), 10, 2 );

		add_filter( 'logout_url', array( &$this, 'xf_logout_redirect' ), 10, 2 );

		add_filter( 'register_url', array( &$this, 'xf_register_redirect' ) );

		add_filter( 'user_dashboard_url', array( &$this, 'xf_dashboard_redirect' ), 10, 4 );

		add_filter( 'network_admin_url', array( &$this, 'xf_admin_url' ), 10, 3 );

		add_filter( 'wp_redirect', array( &$this, 'xf_wp_redirect' ), 10, 1 );

		add_action( 'login_head', array( &$this, 'xf_redirect_login_page' ) );

	}

	/**
	 * Returns the Log In URL.
	 *
	 * Returns the URL that allows the user to log in to the site.
	 *
	 * @param string $login_url The login URL.
	 * @param string $redirect  The path to redirect to on login, if supplied.
	 *
	 * @return string
	 * @throws Zend_Exception
	 */
	function xf_login_redirect( $login_url, $redirect ) {

		$login_url = esc_url( XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('login') );

		$protocol = is_ssl() ? 'https://' : 'http://';
		if ( strpos( $login_url, '?' ) === false ) {
			return $login_url . '?redirect_to=' . $protocol . urlencode( $redirect );
		} else {
			return $login_url . '&redirect_to=' . $protocol . urlencode( $redirect );
		}
	}

	/**
	 * Function redirects logout
	 *
	 * @param string $logout_url The Log Out URL.
	 * @param string $redirect   Path to redirect to on logout.
	 *
	 * @return string
	 * @throws Zend_Exception
	 */
	function xf_logout_redirect( $logout_url, $redirect ) {

		$logout_url = esc_url( XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('logout') );

		$protocol = is_ssl() ? 'https://' : 'http://';
		if ( strpos( $logout_url, '?' ) === false ) {
			return $logout_url . '?redirect_to=' . $protocol . $redirect;
		} else {
			return $logout_url . '&redirect_to=' . $protocol . $redirect;
		}
	}

	/**
	 * Function to modify register url
	 *
	 * @param $url
	 *
	 * @return string
	 */
	function xf_register_redirect( $url ) {
		/** @var $url */
		$url = esc_url( XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('register') );
		return $url;
	}

	/**
	 * Function user dashboard redirect
	 *
	 * @param $url
	 * @param $user_id
	 * @param $path
	 * @param $scheme
	 *
	 * @return string
	 */

	function xf_dashboard_redirect( $url, $user_id, $path, $scheme ) {

		$visitor = XenWord::getVisitor();

		if ( $path == 'profile.php' ) {
			$url = esc_url( XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('members', $visitor) );
			return $url;
		}
		return $url;
	}

	/**
	 * Function admin url
	 *
	 * @param $url
	 * @param $path
	 * @param $blog_id
	 *
	 * @return string
	 */

	function xf_admin_url( $url, $path, $blog_id ) {

		$visitor = XenWord::getVisitor();

		if ( $path == 'profile.php' ) {
			$url = esc_url( XenWord::getBoardUrl() . '/members/' . strtolower( $visitor['username'] ) . '.' . $visitor['user_id'] . '/' );
			return $url;
		}
		return $url;
	}

	/**
	 * Filters the output from the normal wp_redirect function, attempting to catch redirects from wp-admin to the login page
	 *
	 * @param $url
	 *
	 * @return mixed
	 */

	function xf_wp_redirect( $url ) {
		return $url;
	}

	/**
	 * Function to redirect the login page
	 *
	 * @throws Zend_Exception
	 */
	function xf_redirect_login_page() {

		//we should not be able to visit this page ever, but just in case we do let's fill in an HTML redirect
		echo "<meta HTTP-EQUIV='REFRESH' content='0; url="
		     . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('login')
		     . "'>";
		echo "<title>Страница входа переехала</title>";
		echo "<head>";
		echo "<body><h2 style='text-align: center'>Пожалуйста Посетите наш  <a href='"
		     . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('login')
		     . "'>страница входа</a>.</body>";
		echo "</html>";
		die();
	}
}

$xenword_redirects = new XenWord_Redirects();

/**
 * This does the redirects needed if we're doing a register or forgot password action
 */

if ( isset( $_REQUEST['action'] ) ) {
	if ( $_REQUEST['action'] == 'register' ) {
		header( 'location: ' . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('register') );
		exit;
	}
}

if ( $_REQUEST['action'] == 'lostpassword' ) {
	header( 'location: ' . XenWord::getBoardUrl() . '/lost-password' );
	exit;
}

// End class-xenword-redirects.php