<?php

/**
 * Filename: xenword-thread-link.php
 *
 * Creates a link to the XenForo thread below the content in WordPress post
 * Creates a new column in post edit showing and linking to the XenForo forum thread_id
 * Creates a meta box for thread_id in the WordPress post panel
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 3.0.0.01
 *        Added thread link to include font awesome and use of get_comments_number_text()
 */

/**
 * This section is for security. Do not modify this part:
 *
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) { exit; }

class XenWord_ThreadLink {

	public function __construct() {
		$this->hooks();
	}

	public function hooks() {
		add_filter( 'the_content', array( &$this, 'show_link_thread_id' ) );
	}

	/**
	 * Show a link to the XenForo thread at the bottom of a WordPress post
	 * This uses add_filter 'the_content'
	 *
	 * @var $discuss
	 * The variable for the text of the link.
	 * The actual text of the link may be changed in the XenWord panel.
	 *
	 * @param $content
	 *
	 * @return string
	 */
	public function show_link_thread_id( $content ) {

		$xenword_options = get_option( 'xenword_options' );

		if ( $xenword_options['use_thread_link'] == true ) {

			if ( is_singular() && is_main_query() ) {

				$post_id = '';
				$link    = '';
				$discuss = htmlspecialchars( $xenword_options['discussion_text'] );
				$count = '';

				$post = get_post( $post_id, ARRAY_A );

				$thread_id = get_post_custom_values( 'thread_id', $post->ID);
				
				/**
				 * Check if thread_id exists in XenForo and is visible
				 * @since 3.0.0.07
				 * @var $threadModel XenForo_Model_Thread
				 */
				$threadModel = XenForo_Model::create('XenForo_Model_Thread');

				$thread = $threadModel->getThreadById($thread_id[0]);

				// echo '<pre>' . var_export( $thread, true) . '</pre>';

				if ( $thread_id[0] != '' && $thread != false && $thread['discussion_state'] == 'visible' ) {

					if ( $xenword_options['use_comment_link'] == true ) {

						if ( XenWord_Comments::xf_comment_number( $count, $post_id) == 0 || XenWord_Comments::xf_comment_number( $count, $post_id) == '' ) {

							$xenword_thread_link = '<br /><a href=" '
							                       . XenForo_Link::buildPublicLink( 'canonical:threads', $link )
							                       . XenWord::getThreadIdForPost( $post_id )
							                       . '" class="xenword_discuss">'
							                       . '<i class="fa fa-comments"></i> '
							                       . $discuss
							                       . '</a>';

						} elseif ( XenWord_Comments::xf_comment_number( $count, $post_id) == 1 ) {

							$xenword_thread_link = '<br /><a href=" '
							                       . XenForo_Link::buildPublicLink( 'canonical:threads', $link )
							                       . XenWord::getThreadIdForPost( $post_id )
							                       . '" class="xenword_discuss">'
							                       . '<i class="fa fa-comments"></i> '
							                       . XenWord_Comments::xf_comment_number( $count, $post_id )
							                       . ' comment'
							                       . '</a>';

						} else {

							$xenword_thread_link = '<br /><a href=" '
							                       . XenForo_Link::buildPublicLink( 'canonical:threads', $link )
							                       . XenWord::getThreadIdForPost( $post_id )
							                       . '" class="xenword_discuss">'
							                       . '<i class="fa fa-comments"></i> '
							                       . XenWord_Comments::xf_comment_number( $count, $post_id )
							                       . ' comments'
							                       . '</a>';

						} // end if/elseif/else xf_comment_number

					} else {

						$xenword_thread_link = '<br /><a href=" '
						                       . XenForo_Link::buildPublicLink( 'canonical:threads', $link )
						                       . XenWord::getThreadIdForPost( $post_id )
						                       . '" class="xenword_discuss">'
						                       . $discuss
						                       . '</a>';

					} // end if/else use_comment_link

					// echo '<ore>' . var_dump(debug_backtrace()) . '</pre>';

					$content .= $xenword_thread_link;


				} // end $thread_id[0] != 0 && $thread != false && $thread['discussion_state'] == 'visible'

			}

		} // end use_thread_link conditional

		/** return the content */
		return $content;

	}

	/**
	 * Pull a count from the XenForo side
	 * This count will not include older comments before linking post to a thread
	 *
	 * @param $count
	 * @param $post_id
	 *
	 * @return mixed
	 *
	public function xf_comment_number( $count, $post_id ) {

		global $XF;
		if ( XenWord::useXenForoCommentHandler() ) {

			return $XF->getCommentNumbersFromCache( $post_id );

		} else {

			return $count;
		}
	}*/



}

new XenWord_ThreadLink();





// End class-xenword-thread-link.php