<?php

/**
 * Filename: class-xenword-toolbar.php
 *
 * Show alerts, conversations, and likes in the WordPress toolbar
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 1.0.7.01
 *        Conditional to show link to XenWord settings
 * @since 2.1.0.03
 *        Added likes
 *
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

Class XenWord_Toolbar {

	public function __construct() {
		$this->load();
	}

	public function load() {

		/** The add_action # is the menu position
		 * 10 = Before the WP Logo
		 * 15 = Between the logo and My Sites
		 * 25 = After the My Sites menu
		 * 100 = End of menu
		 */

		add_action( 'admin_bar_menu', array( &$this, 'toolbar'), 100 );

		add_action( 'wp_before_admin_bar_render', array( &$this, 'remove_admin_bar_links' ) );
	}

	/**
	 * @param $wp_admin_bar
	 *
	 * @throws Zend_Exception
	 */
	function toolbar( $wp_admin_bar ) {

		$xenword_options = get_option( 'xenword_options' );

		$visitor = XenWord::getVisitor();

		if ( $xenword_options['use_xenword_conversations'] == true ) {

			/**
			 * To move the location of the conversations and alerts on the Toolbar
			 *
			 * 'parent' => 'user-actions',
			 * 'parent' => 'top-secondary',
			 * 'parent' => 'my-account',
			 */

			$args1 = array(
				'id'    => 'conversations',
				'title' => '<span class="ab-icon"></span>' . __( 'Входящие ', 'xenword' )
			);

			$args2 = array(
				'id'    => 'conversations_unread',
				'title' => $visitor['conversations_unread'] . ' ',
				'href'  => XenWord::getBoardUrl() . '/conversations'
			);

			$wp_admin_bar->add_node( $args1 );
			$wp_admin_bar->add_node( $args2 );
		}

		if ( $xenword_options['use_xenword_alerts'] == true ) {

			$args3 = array(
				'id'    => 'alerts',
				'title' => '<span class="ab-icon"></span>' . __( 'Оповещения ', 'xenword' )
			);

			$args4 = array(
				'id'    => 'alerts_unread',
				'title' => $visitor['alerts_unread'] . ' ',
				'href'  => XenWord::getBoardUrl() . '/account/alerts'
			);

			$wp_admin_bar->add_node( $args3 );
			$wp_admin_bar->add_node( $args4 );

		}

		if ( $xenword_options['use_xenword_likes'] == true ) {
			/**
			 * @since 2.1.0.03
			 */

			$args7 = array(
				'id'    => 'likes',
				'title' => '<span class="ab-icon"></span>' .__( 'Likes ', 'xenword' )
			);

			$args8 = array(
				'id'    => 'likes_count',
				'title' => $visitor['like_count']
			);

			/** @var add_node $wp_admin_bar */
			$wp_admin_bar->add_node( $args7 );
			$wp_admin_bar->add_node( $args8 );
		}

		if ( $xenword_options['use_xenword_toolbar_settings'] == true && is_admin() && current_user_can('administrator') ) {

			/**
			 * @since 1.0.7.01
			 */

			$args5 = array(
				'id'    => 'xenword',
				'title' => __( 'XenWord', 'xenword' ),
			);

			$args6 = array(
				'id'     => 'xenword_settings',
				'parent' => 'xenword',
				'title'  => 'Settings',
				'href'   => '/wp-admin/admin.php?page=xenword'
			);

			$wp_admin_bar->add_menu( $args5 );
			$wp_admin_bar->add_menu( $args6 );

		}
	}


	function remove_admin_bar_links() {

		$xenword_options = get_option( 'xenword_options' );

		if ( $xenword_options['use_wordpress_toolbar'] == false ) {

			if ( ! current_user_can( 'manage_options' ) ) {

				global $wp_admin_bar;

				$wp_admin_bar->remove_menu( 'wp-logo' );          // Remove the WordPress logo
				$wp_admin_bar->remove_menu( 'about' );            // Remove the about WordPress link
				$wp_admin_bar->remove_menu( 'wporg' );            // Remove the WordPress.org link
				$wp_admin_bar->remove_menu( 'documentation' );    // Remove the WordPress documentation link
				$wp_admin_bar->remove_menu( 'support-forums' );   // Remove the support forums link
				$wp_admin_bar->remove_menu( 'feedback' );         // Remove the feedback link
				$wp_admin_bar->remove_menu( 'site-name' );        // Remove the site name menu
				$wp_admin_bar->remove_menu( 'view-site' );        // Remove the view site link
				$wp_admin_bar->remove_menu( 'updates' );          // Remove the updates link
				$wp_admin_bar->remove_menu( 'comments' );         // Remove the comments link
				$wp_admin_bar->remove_menu( 'new-content' );      // Remove the content link
				$wp_admin_bar->remove_menu( 'w3tc' );             // If you use w3 total cache remove the performance link
				$wp_admin_bar->remove_menu( 'my-account' );       // Remove the user details tab

			} else {

				// Leave the toolbar alone

			}
		}
	}
}

new XenWord_Toolbar();

// End class-xenword-toolbar.php