<?php

/**
 * Filename: class-xenword-wordpress-comments.php
 *
 * Grabs the WordPress comments and writes the comments to the XenForo xf_post table.
 *
 * @author      LPH
 * @version     3.0.0.08
 * @package     XenWord
 * @subpackage  /WordPress/includes
 *
 * @since 3.0.0.08
 *        Initial release
 */

class XenWord_WordPress_Comments {

	public $comment;

	/**
	 * XenWord_Comments constructor.
	 */
	public function __construct() {

		add_action( 'preprocess_comment', array( $this, 'write' ), 10, 1 );
		add_action( 'comment_post', array( $this, 'add_meta' ), 10, 1 );
	}

	/**
	 * Write the $comment to the XenForo database
	 *
	 * @param $comment
	 *
	 * @return mixed
	 */
	public function write( $comment ) {

		/**
		 * Loads the XenWord options saved in the XenWord panel.
		 *
		 * @var  $xenword_options
		 */
		$xenword_options = get_option( 'xenword_options' );

		/** Are we displaying comments in WP? */
		if ( $xenword_options['display_comments_in_wp'] == true ) {

			$thread_id = XenWord::getThreadIdForPost( $comment['comment_post_ID'] );

			$parser = new XenForo_BbCode_Parser( new XenForo_BbCode_Formatter_Wysiwyg );

			$visitor = XenWord::getVisitor();

			if ( $thread_id !== false && $thread_id !== null && $visitor['is_banned'] != 1 ) {

				/** @var  $threadModel XenForo_Model_Thread */
				$threadModel = XenForo_Model::create( 'XenForo_Model_Thread' )->getModelFromCache( 'XenForo_Model_Thread' );

				/** @var  $forumModel XenForo_Model_Forum */
				$forumModel = XenForo_Model::create( 'XenForo_Model_Forum' )->getModelFromCache( 'XenForo_Model_Forum' );
				$thread     = $threadModel->getThreadById( $thread_id );
				$forum      = $forumModel->getForumById( $thread['node_id'] );

				$errorPhraseKey = '';
				if ( $threadModel->canReplyToThread( $thread, $forum, $errorPhraseKey )
				) {

					if ( ! $visitor->hasPermission( 'general', 'bypassFloodCheck' ) ) {
						$floodTimeRemaining = XenForo_Model_FloodCheck::checkFlooding( 'post', null );

						if ( $floodTimeRemaining ) {
							wp_die( 'Пользователь flooding. Не удается обработать комментарий' );
						}
					}

					$user_id = $visitor['user_id'];

					$writer = XenForo_DataWriter::create( 'XenForo_DataWriter_DiscussionMessage_Post' );
					$writer->set( 'user_id', $user_id );
					$writer->set( 'username', $visitor['username'] );

					$new_wordpress_comment_content = $parser->render( $comment['comment_content'] ); //convert the BBCode they typed to HTML

					if ( $comment['comment_parent'] != '0' ) { //Handle automatically adding quotes for replies

						/** @var  $postModel XenForo_Model_Post */
						$postModel = XenForo_Model::create( 'XenForo_Model_Post' )
							               ->getModelFromCache( 'XenForo_Model_Post' );
						$post = $postModel->getPostById( $comment['comment_parent'] );
						$comment['comment_content'] = '[quote="'
						                              . $post['username']
						                              . ', post: '
						                              . $comment['comment_parent']
						                              . '"]'
						                              . $post['message']
						                              . '[/quote]'
						                              . $comment['comment_content'];
					}

					$writer->set( 'message', stripslashes( $comment['comment_content'] ) );
					$comment['comment_content'] = $new_wordpress_comment_content;

					/** @var  $postModel XenForo_Model_Post */
					$postModel = XenForo_Model::create( 'XenForo_Model_Post' )->getModelFromCache( 'XenForo_Model_Post' );
					$writer->set( 'message_state', $postModel->getPostInsertMessageState( $thread, $forum ) );
					$writer->set( 'thread_id', $thread_id );

					/**
					 * Guest Post
					 */
					if ( $user_id == 0 ) {
						$writer->set( 'username', $comment['comment_author'] );
					}

					$writer->setExtraData( XenForo_DataWriter_DiscussionMessage::DATA_ATTACHMENT_HASH, '' );
					$writer->preSave();

					if ( ! $writer->hasErrors() ) {
						$writer->save();

						global $XF;
						$XF->insertion_id  = $writer->get( 'post_id', 'xf_post' );

					}
				}
			}
		}
		return $comment;
	}

	/**
	 * Writes the post_id and thread_id to the _commentmeta table
	 * based on the comment_id
	 *
	 * @param $comment_id
	 *
	 * @since 3.0.1.02
	 *        Initial release
	 *
	 * @throws XenForo_Exception
	 */
	public function add_meta( $comment_id ) {

		global $XF;

		// the XenForo post ID corresponding to the comment
		$xf_post_id = $XF->insertion_id;

		if ( isset( $xf_post_id ) ) {
			update_comment_meta( $comment_id, 'post_id', $xf_post_id );
		}

		// Get the comment array for comment_id
		$comments = get_comment( $comment_id, ARRAY_A );

		// Get the XenForo thread_id from the comment post ID
		$thread_id = XenWord::getThreadIdForPost( $comments['comment_post_ID'] );

		if ( isset ( $thread_id ) ) {
			update_comment_meta( $comment_id, 'thread_id', $thread_id );
		}
	}
}

new XenWord_WordPress_Comments();

// End class-xenword-wordpress-comments.php