<?php

/**
 * File Name: xenword-dashboard-widget.php
 * Description: Shows Latest XenWord Information in a dashboard widget
 *
 * @author      LPH
 * @version     3.0.2.02
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 3.0.2.02
 *        Initial Release
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

add_action( 'wp_dashboard_setup', 'register_xenword_dashboard_widget' );
function register_xenword_dashboard_widget() {
	wp_add_dashboard_widget(
		'xenword_dashboard_widget',
		'XenWord Information',
		'xenword_dashboard_widget_display'
	);

}

function xenword_dashboard_widget_display() {
	$xenword_options = get_option( 'xenword_options' );

	/** @var $countersModel XenForo_Model_Counters */
	$countersModel = XenForo_Model::create( 'XenForo_Model_Counters' );
	$total_counts = $countersModel->getBoardTotalsCounter();

	echo '<div class="stats">';
	echo '<dl class="pairsJustified discussions"><dt>Обсуждения:</dt><dd> ' . XenForo_Locale::numberFormat( $total_counts['discussions'] ) . '</dd></dl>';
	echo '<dl class="pairsJustified messages"><dt>Сообщения:</dt><dd>' . XenForo_Locale::numberFormat( $total_counts['messages'] ) . '</dd></dl>';
	echo '<dl class="pairsJustified members"><dt>Участники:</dt><dd> ' . XenForo_Locale::numberFormat( $total_counts['users'] ) . '</dd></dl>';

	if ( $xenword_options['use_media'] == true ) {

		$media_counts = XenForo_Application::getSimpleCacheData('xengalleryStatisticsCache');

		echo '<dl class="pairsJustified media"><dt>Media:</dt><dd> ' . XenForo_Locale::numberFormat( $media_counts['album_count'] ) . '</dd></dl>';
	}

	if ( $xenword_options['use_showcase'] == true ) {

		$showcase_counts = XenForo_Application::getSimpleCacheData('showcaseStatsCache');

		echo '<dl class="pairsJustified showcase"><dt>Витрина:</dt><dd> ' . XenForo_Locale::numberFormat( $showcase_counts['items'] ) . '</dd></dl>';
	}

	if ( $xenword_options['use_ams'] == true ) {

		$ams_counts = XenForo_Application::getSimpleCacheData('amsStatsCache');

		echo '<dl class="pairsJustified ams"><dt>Статьи:</dt><dd> ' . XenForo_Locale::numberFormat( $ams_counts['articles'] ) . '</dd></dl>';
	}

	if ( $xenword_options['use_xenreviews'] == true ) {

		/** @var  $xenreviewsModel XenReviews_Model_Review */
		$xenreviewsModel = XenReviews_Model_Review::create('XenReviews_Model_Review')->getModelFromCache('XenReviews_Model_Review');

		$xenreviews_counts = $xenreviewsModel->countVisibleReviews();

		/** @var $xenreviews_counts */
		echo '<dl class="pairsJustified xenReviews"><dt>Отзывы:</dt><dd> ' . XenForo_Locale::numberFormat( $xenreviews_counts ) . '</dd></dl>';
	}

	echo '<dl class="pairsJustified latestMembers"><dt>Последний участник:</dt><dd> ' . '<a href="' . XenWord::getBoardUrl() . '/members/' . $total_counts['latestUser']['user_id'] . '">' . $total_counts['latestUser']['username'] . '</a>' . '</dd></dl>';
	echo '</div>';
}

// End xenword-dashboard-widget.php