<?php

/**
 * File Name: xenword-xf-boardtotals-widget.php
 *
 * Description: Shows the community statistics created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.0.01
 *
 * @since 3.0.0.01
 *        Added link to latestUser
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Class XenWordXFStats
 */
class XenWordXFStats extends WP_Widget {

	/** Register the widget */
	public function __construct() {

		parent::__construct(
			// Base ID of your widget
			'xenword_board_totals_widget',

			// Widget name will appear in UI
			__('XenForo Доска итого', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать статистику сообщества', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 *
	 */
	public function widget( $args, $instance ) {

		$xenword_options = get_option( 'xenword_options' );

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var $countersModel XenForo_Model_Counters */
		$countersModel = XenForo_Model::create( 'XenForo_Model_Counters' );
		$total_counts = $countersModel->getBoardTotalsCounter();

		echo '<div class="stats">';
		echo '<dl class="pairsJustified discussions"><dt>Discussions:</dt><dd> ' . XenForo_Locale::numberFormat( $total_counts['discussions'] ) . '</dd></dl>';
		echo '<dl class="pairsJustified messages"><dt>Messages:</dt><dd>' . XenForo_Locale::numberFormat( $total_counts['messages'] ) . '</dd></dl>';
		echo '<dl class="pairsJustified members"><dt>Members:</dt><dd> ' . XenForo_Locale::numberFormat( $total_counts['users'] ) . '</dd></dl>';

		if ( $xenword_options['use_media'] == true ) {

			$media_counts = XenForo_Application::getSimpleCacheData('xengalleryStatisticsCache');

			echo '<dl class="pairsJustified media"><dt>Media:</dt><dd> ' . XenForo_Locale::numberFormat( $media_counts['album_count'] ) . '</dd></dl>';
		}

		if ( $xenword_options['use_showcase'] == true ) {

			$showcase_counts = XenForo_Application::getSimpleCacheData('showcaseStatsCache');

			echo '<dl class="pairsJustified showcase"><dt>Витрина:</dt><dd> ' . XenForo_Locale::numberFormat( $showcase_counts['items'] ) . '</dd></dl>';
		}

		if ( $xenword_options['use_ams'] == true ) {

			$ams_counts = XenForo_Application::getSimpleCacheData('amsStatsCache');

			echo '<dl class="pairsJustified ams"><dt>Статьи:</dt><dd> ' . XenForo_Locale::numberFormat( $ams_counts['articles'] ) . '</dd></dl>';
		}

		if ( $xenword_options['use_xenreviews'] == true ) {

			/** @var  $xenreviewsModel XenReviews_Model_Review */
			$xenreviewsModel = XenReviews_Model_Review::create('XenReviews_Model_Review')->getModelFromCache('XenReviews_Model_Review');

			$xenreviews_counts = $xenreviewsModel->countVisibleReviews();

			/** @var $xenreviews_counts */
			echo '<dl class="pairsJustified xenReviews"><dt>Отзывы:</dt><dd> ' . XenForo_Locale::numberFormat( $xenreviews_counts ) . '</dd></dl>';
		}

		echo '<dl class="pairsJustified latestMembers"><dt>Последний участник:</dt><dd> ' . '<a href="' . XenWord::getBoardUrl() . '/members/' . $total_counts['latestUser']['user_id'] . '">' . $total_counts['latestUser']['username'] . '</a>' . '</dd></dl>';
		echo '</div>';

		echo '<hr class="xenword-login-line">';

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	/**
	 * Widget Backend
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance
	 *
	 * @return string
	 */

	public function form( $instance ) {

		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Статистика сообщества', 'xenword' );
		}

		$defaults = array('title'=>'');

		/** @var $instance */
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

	<?php
		return 'noform';
	}

	/**
	 * Sanitize widget form values as they are saved
	 * Updating widget replacing old instances with new
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance
	 * @param array $old_instance
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
}

add_action( 'widgets_init', function() {
	register_widget( 'XenWordXFStats' );
});

// End xenword-xf-boardtotals-widget.php