<?php

/**
 * File Name: xenword-xf-forum-by-category-widget.php
 *
 * Description: Shows a list of forums in a community created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 2.0.2.02
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFForums extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_forum_widget',

			// Widget name will appear in UI
			__( 'XenForo Форумы', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать форумы в вашей общине. Ограниченная по категориям.', 'xenword' ) )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 * @throws XenForo_Exception
	 * @throws Zend_Exception
	 */
	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var  $forumModel XenForo_Model_Forum */
		$forumModel = XenForo_Model_Forum::create('XenForo_Model_Forum');

		$visitor = XenWord::getVisitor();

		$number_of_forums = $instance['show_number_of_forums'];

		$category['title'] = $instance['show_categories'];

		$cat_id = $category['title'];

		/** Script to pull the forums from XenForo */

		/** @var $node_qry XenWordXFForums */
		$node_qry = "
		            SELECT node_id, title, display_in_list, node_type_id, parent_node_id FROM `xf_node`
		            WHERE display_in_list = 1 AND node_type_id = 'Forum' AND parent_node_id = ' . $cat_id . '
		            ORDER BY `title` ASC
		            LIMIT ' . $number_of_forums . '
					";

		$nodes = XenForo_Application::get( 'db' )->fetchAll( $node_qry );

		foreach ( $nodes AS $node ) {

			$visitor->setNodePermissions( $node['node_id'], $node['node_permission_cache'] );
			if ( $forumModel->canViewForum( $node ) ) {

				echo(
					"<div class='entry-meta'><a href='"
					. XenForo_Link::buildPublicLink( 'canonical:forums', $node )
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $node['title'], 40 )
					. "</a><br />"
				);
			}
		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Форумы сообщества по категориям', 'xenword' );
		}

		$category['title'] = $instance['show_categories'];

		$defaults = array( 'show_number_of_forums' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		/** @var $category_qry XenWordXFForums */
		$category_qry = "
		            SELECT node_id, title, display_in_list, node_type_id FROM xf_node
		            WHERE display_in_list = 1 AND node_type_id = 'Category'
		            ORDER BY `title` ASC
					";

		$categories = XenForo_Application::get( 'db' )->fetchAll( $category_qry );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_categories' ); ?>">Категория:</label>
			<select id="<?php echo $this->get_field_id( 'show_categories' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_categories' ); ?>">
				<?php foreach ( $categories AS $category ) {
					echo '<option value="' . $category['node_id'] . '"';
					if ( $category['node_id'] == $instance['show_categories'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $category['title'] . '</option>';
				} ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_number_of_forums' ); ?>">Число форумов:</label>
			<select id="<?php echo $this->get_field_id( 'show_number_of_forums' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_number_of_forums' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['show_number_of_forums'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}

	/**
	 * Updating widget replacing old instances with new
	 *
	 * @param array $new_instance
	 * @param array $old_instance
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['show_number_of_forums'] = $new_instance['show_number_of_forums'];
		$instance['show_categories'] = $new_instance['show_categories'];

		return $instance;
	}
}

add_action( 'widgets_init', create_function( '', 'return register_widget("XenWordXFForums");' ) );

// End xenword-xf-forum-by-category-widget.php