<?php

/**
 * File Name: xenword-xf-forum-feature-version-2-widget.php
 *
 * Description: Version 2. Feature a forum created by XenForo.
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.03.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordFeatureForum2 extends WP_Widget {
	
	function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_feature_forum_2_widget',
			
			// Widget name will appear in UI
			__('XenForo Рекомендуемые форум альфа v2', 'xenword'),
			
			// Widget description
			array( 'description' => __( 'Версия 2: Покажите XenForo форум из вашей общины. Это не работает должным образом.', 'xenword' ) )
		);
	}
	
	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */
	
	function widget( $args, $instance ) {
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme
		
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		// $xenword_options = get_option( 'xenword_options' );

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create( 'XenForo_Model_Thread' );

		$forum = $instance['show_forum_number'];

		$conditions = array();

		$limit = $instance['number_of_posts'];

		$fetchOptions = array(
			'join' => XenForo_Model_Thread::FETCH_FIRSTPOST,
			'order' => 'post_date',
			'orderDirection' => 'desc',
			'limit' => $limit,
		);

		$threads = $threadModel->getThreadsInForum( $forum, $conditions, $fetchOptions );

		$feature_node_id = $instance['show_forum_number'];

		$dependencies = new XenForo_Dependencies_Public();
		$dependencies->preLoadData();

		/* Get the visitor param */
		$visitor = XenWord::getVisitor();

		$styleId = $visitor['style_id'];

		if ( $styleId > 0 ) {
			XenForo_Template_Public::setStyleId( $styleId );
		} else {
			XenForo_Template_Public::setStyleId( 1 );
		}

		$languageId = $visitor['language_id'];

		if ( $languageId > 0 ) {
			XenForo_Template_Abstract::setLanguageId( $languageId );
		} else {
			XenForo_Template_Abstract::setLanguageId( 1 );
		}

		$dependencies->preRenderView();
		$params = $dependencies->getEffectiveContainerParams(array(), new Zend_Controller_Request_Http());

		$params['threads'] = $threads;
		$params['visitor'] = $visitor;
		$params['forum'] = 'raw';
		$params['totalThreads'] = $limit;
		$params['perPage'] = '20';
		$params['order'] = '1';
		$params['orderDirection'] = 'desc';
		/**
		$params = array(
			'visitor'      => $visitor,
			'node_id'  => $feature_node_id,
			'threads'   => $threads,
			'forum'     => 'raw',
			'totalThreads' => $limit,
			'perPage' => '20',
			'page' => '',
			'order' => '1',
			'orderDirection' => ''
		);
		 * */

		/**
		 * This template requires a link to the XenForo CSS.
		 * XenForo CSS is dynamically created.
		 */

		// XenForo_Controller::actionIndex();

		// echo $this->responseView('XenForo_ViewAdmin_Thread_List', 'thread_list', $params);

		$template = $dependencies->createTemplateObject( 'thread_list', $params );

		echo $template->render();

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}
	
	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Feature A Forum', 'xenword' );
		}
		
		$defaults = array( 'number_of_posts' => '5', 'show_forum_number' => '', 'title'=>'' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		$feature_node_qry = '
					SELECT node_id, title, display_in_list, node_type_id FROM `xf_node`
					WHERE display_in_list = 1 AND node_type_id = "Forum"
		            ORDER BY `title` ASC
					';
		
		$feature_nodes = XenForo_Application::get( 'db' )->fetchAll( $feature_node_qry );
		
		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'show_forum_number' ); ?>">Форум:</label>
			<select id="<?php echo $this->get_field_id( 'show_forum_number' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_forum_number' ); ?>">
				<?php foreach ( $feature_nodes AS $feature_node ) {
					echo '<option value="' . $feature_node['node_id'] . '"';
					if ( $feature_node['node_id'] == $instance['show_forum_number'] ) {
						echo ' selected="selected"';
					}
					echo '>' . XenForo_Helper_String::wholeWordTrim( $feature_node['title'] , 38 ) . '</option>';
				} ?>
			</select>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'number_of_posts' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'number_of_posts' ); ?>"
			        name="<?php echo $this->get_field_name( 'number_of_posts' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['number_of_posts'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}
	
	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['show_forum_number'] = $new_instance['show_forum_number'];
		$instance['number_of_posts'] = $new_instance['number_of_posts'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordFeatureForum2");' )
);

// End xenword-xf-forum-feature-version-2-widget.php