<?php

/**
 * File Name: xenword-xf-forum-feature-widget.php
 *
 * Description: Features a forum created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.03.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordFeatureForum extends WP_Widget {

	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'xenword_xf_feature_forum_widget',

			// Widget name will appear in UI
			__('XenForo Рекомендуемые форум', 'xenword'),

			// Widget description
			array( 'description' => __( 'Показать Форум XenForo от вашего сообщества', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var  $featured_threadModel XenForo_Model_Thread */
		$featured_threadModel = XenForo_Model::create( 'XenForo_Model_Thread' );

		$featured_forum = $instance['show_forum_number'];

		$number_of_posts = $instance['number_of_posts'];

		$conditions = array();

		$fetchOptions = array(
			'join' => XenForo_Model_Thread::FETCH_FIRSTPOST,
			'node_id'  => $featured_forum,
			'order' => 'post_date',
			'orderDirection' => 'desc',
			'limit' => $number_of_posts
		);

		$featured_forum_threads = $featured_threadModel->getThreadsInForum( $featured_forum, $conditions, $fetchOptions );

		//$dependencies = new XenForo_Dependencies_Public();

		//$dependencies->preLoadData();

		echo "<table><tr style='background: aliceblue;'><td>Начало темы</td><td>Title</td><td>Дата начала</td></tr>";

		foreach ( $featured_forum_threads as $featured_forum_thread) {

			$threadTitle        = $featured_forum_thread['title'];
			$threadDate         = date( "m.d.y", $featured_forum_thread['post_date'] );
			$author             = $featured_forum_thread['username'];
			$replyCount         = $featured_forum_thread['reply_count'];
			$viewCount          = $featured_forum_thread['view_count'];
			$lastPostUsername   = $featured_forum_thread['last_post_username'];

			$featured_threadUrl = XenForo_Link::buildPublicLink( 'canonical:threads', $featured_forum_thread );

			echo "
				<tr><td>$author</td>
	          	<td><a href=\"$featured_threadUrl\">{$threadTitle}</a>
	          	<td>$threadDate</td>
	            </td></tr>
           ";

		}

		echo "</table>";

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Рекомендуемый Форум', 'xenword' );
		}
		
		$defaults = array( 'number_of_posts' => '5', 'show_forum_number' => '', 'title'=>'' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		$feature_node_qry = '
					SELECT node_id, title, display_in_list, node_type_id FROM `xf_node`
					WHERE display_in_list = 1 AND node_type_id = "Forum"
		            ORDER BY `title` ASC
					';

		$feature_nodes = XenForo_Application::get( 'db' )->fetchAll( $feature_node_qry );
		
		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'show_forum_number' ); ?>">Форум:</label>
			<select id="<?php echo $this->get_field_id( 'show_forum_number' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_forum_number' ); ?>">
				<?php foreach ( $feature_nodes AS $feature_node ) {
					echo '<option value="' . $feature_node['node_id'] . '"';
					if ( $feature_node['node_id'] == $instance['show_forum_number'] ) {
						echo ' selected="selected"';
					}
					echo '>' . XenForo_Helper_String::wholeWordTrim( $feature_node['title'] , 38 ) . '</option>';
				} ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number_of_posts' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'number_of_posts' ); ?>"
			        name="<?php echo $this->get_field_name( 'number_of_posts' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['number_of_posts'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['show_forum_number'] = $new_instance['show_forum_number'];
		$instance['number_of_posts'] = $new_instance['number_of_posts'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordFeatureForum");' )
);

// End xenword-xf-forum-feature-widget.php