<?php

/**
 * File Name: xenword-xf-login-widget.php
 *
 * Description: The WordPress login, register widget for XenForo accounts
 *
 * This WordPress widget contains a XenForo login, logout, register, and
 * profile links. The css may be found in the public xenword-public.css.
 * Options are available to login via Facebook, Twitter, and Google
 *
 * @author      LPH
 * @author      Shabbir
 * @version     3.0.2.03
 * @package     XenWord
 * @subpackage  WordPress/includes/widgets
 *
 * @since 1.0.03.01
 *        Initial release
 *
 * @since 3.0.2.03
 *        Fixed hardcoding of login/login, register, accounts, members
 *        Removed logged-in message
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFLogin extends WP_Widget {

	public function __construct() {

		parent::__construct(
		// Base ID of your widget
			'xenword_login_widget',

			// Widget name will appear in UI
			__('XenForo Логин', 'xenword'),

			// Widget description
			array( 'description' => __( 'Показать имя входа / регистрации формы для XenForo сообщества', 'xenword' ) )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );
		$message_loggedIn = $instance['loggedIn_message'];

		extract( $args, EXTR_SKIP );

		$redirect = wp_guess_url() . $_SERVER['REQUEST_URI'];

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( !is_user_logged_in() ) {

			if ( ! empty( $title ) ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			?>
			<div id="xenlogin">
				<form action="<?php echo XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('login/login'); ?>" method="post" id="pageLogin">
					<div class="ctrlWrapper">
						<dl class="ctrlUnit">
							<label for="LoginControl">Ваше имя или email адрес:</label><br />
							<input type="text" size="15" name="login" id="LoginControl" class="textCtrl" tabindex="101" /><br />

							<label for="ctrl_password">Пароль:</label><br />
							<input type="password" size="15" name="password" id="ctrl_password" class="textCtrl" tabindex="102" /><br />

							<input type="submit" class="button primary" value="Войти" tabindex="104" />
							<label for="ctrl_remember" class="rememberPassword">
								<input type="checkbox" name="remember" value="1" id="ctrl_remember" tabindex="103" /> запомнить</label>
						</dl>
					</div>
					<input type="hidden" name="cookie_check" value="0" />
					<input type="hidden" name="redirect" value="<?php echo $redirect ?>" />
					<input type="hidden" name="_xfToken" value="" />
				</form>

				<?php echo '<a href="' . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('lost-password') . '">Forgot your password?</a>'; ?>

				<br />
				<?php echo '<a class="xenword_signup" href="' . XenWord::getBoardUrl() . '/'. XenForo_Link::buildPublicLink( 'register', null, array( 'redirect' => $redirect ) ) . '">Sign up now!</a>'; ?>

				<?php

				$xenword_options = get_option( 'xenword_options' );

				if ( $xenword_options['use_facebook'] == true ) {
					echo '<br /><a class="xenword_fbLogin" href="' . XenWord::getBoardUrl() . '/register/facebook?reg=1"><span>Войти с Facebook</span></a>';
				}

				if ( $xenword_options['use_twitter'] == true ) {
					echo '<br /><a class="xenword_twitterLogin" href="' . XenWord::getBoardUrl() . '/register/twitter?reg=1"><span>Войти с Twitter</span></a>';
				}

				if ( $xenword_options['use_google'] == true ) {
					echo '<span class="googleLogin GoogleLogin JsOnly" tabindex="110" data-client-id="531377224319.apps.googleusercontent.com" data-redirect-url="' . XenWord::getBoardUrl() . '/register/google?code=__CODE__&amp;csrf=7TMaP5TirQ9UhUh0" data-gapiattached="true"><span>Log in with Google</span></span>';
				} ?>
			</div>

			<?php

		} else {

			$visitor = XenWord::getVisitor();

			if ( ! empty( $title ) ) {
				echo $args['before_title'] . 'Your Profile' . $args['after_title'];
			}

			?>

			<div id="xenlogin">

				<?php if ( $visitor['user_state'] == 'email_confirm' ) {
					$message_loggedIn = str_replace(
						array( '{username}', '{email}' ),
						array( $visitor['username'], $visitor['email'] ),
						$message_loggedIn );
					echo '<div class="notice">' . $message_loggedIn
					     . '</div><br />';
				}
				?>
				<?php echo '<a class="xenword_profile avatar" href="' . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('account') . '">'; ?>
				<?php echo get_avatar( get_current_user_id(), 96 ) . '</a>'; ?>

				<div class="visitorText">

					<?php echo '<h2 class="xenword_profile"><a class="username" href="' . XenWord::getBoardUrl() . '/'. XenForo_Link::buildPublicLink('members', $visitor) . '">' ?>
					<?php echo '' . $visitor['username'] . '</a></h2><br />'; ?>

					<div class="stats">
						<?php echo '<dl class="pairsJustified messages"><dt>Сообщения:</dt><dd>' . XenForo_Locale::numberFormat( $visitor['message_count'] ) . '</dd></dl>'; ?>
						<?php echo '<dl class="pairsJustified likes"><dt>Likes:</dt><dd>' . XenForo_Locale::numberFormat( $visitor['like_count'] ) . '</dd></dl>'; ?>
						<?php echo '<dl class="pairsJustified trophies"><dt>Очки:</dt><dd>' . XenForo_Locale::numberFormat( $visitor['trophy_points'] ) . '</dd></dl>'; ?>
					</div>

				</div>

				<br />

				<div class="xenword_login forms">
					<?php echo '<a class="xenword_logout logout" href="' . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('account') . '">Edit Profile</a>'; ?>
					<?php echo '<a class="xenword_logout logout" href="' . XenWord::getBoardUrl() . '/' . XenForo_Link::buildPublicLink('logout', $visitor, array( '_xfToken' => $visitor['csrf_token_page'], 'redirect' => $redirect) ). '">Logout</a>'; ?>
				</div>
			</div>

			<?php
		}
		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		$defaults = array( 'title'=>'Вход на сайт',
		                  'loggedIn_message' => '{username}, Ваша учетная запись включена в настоящее время '
		                                        . 'в ожидании подтверждения электронной почты. Ваш адрес электронной почты {email}.' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		$title = $instance[ 'title' ];
		$message_loggedIn = esc_html( $instance['loggedIn_message'] );

		/** Widget admin form */
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('loggedIn_message'); ?>"><?php _e( 'Неподтвержденные сообщения email Пользователей:' ); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'loggedIn_message' ); ?>" name="<?php echo $this->get_field_name( 'loggedIn_message') ; ?>"><?php echo $message_loggedIn; ?></textarea>
		</p>

		<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['loggedIn_message'] = strip_tags($new_instance['loggedIn_message']);
		return $instance;
	}
}

add_action( 'widgets_init', create_function( '', 'return register_widget("XenWordXFLogin");' ) );

// End xenword-xf-login-widget.php