<?php

/**
 * File Name: xenword-notice-widget.php
 *
 * Description: Shows a notice created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.03.02
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordNotices extends WP_Widget {

	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'xenword_xf_notice_widget',

			// Widget name will appear in UI
			__('XenForo Уведомления', 'xenword'),

			// Widget description
			array( 'classname' => 'xf_widgets', 'description' => __( 'Показать XenForo уведомление от вашего сообщества', 'xenword' ) )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/* Script to pull a notice from the XF */

		/** @var  $noticesModel XenForo_Model_Notice */
		$noticesModel = XenForo_Model::create('XenForo_Model_Notice')->getModelFromCache('XenForo_Model_Notice');
		$notices = $noticesModel->getNoticeById( $instance['noticenumber'] );

		echo $notices['message'];

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Community Notice', 'xenword' );
		}

		$notice_id = $instance[ 'noticenumber' ];

		$defaults = array('noticenumber' => '1', 'title'=>$title);

		/** @var $instance */
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'noticenumber' ); ?>"><?php _e( 'Уведомление ID:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'noticenumber' ); ?>" name="<?php echo $this->get_field_name( 'noticenumber' ); ?>" type="text" value="<?php echo esc_attr( $notice_id ); ?>" />
		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['noticenumber'] = $new_instance['noticenumber'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordNotices");' )
);

// End xenword-xf-notice-widget.php