<?php

/**
 * File Name: xenword-xf-onlineusers-widget.php
 *
 * Description: Shows the online users in the community connect created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.0.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFUsers extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_online_users_widget',

			// Widget name will appear in UI
			__( 'XenForo Пользователи онлайн', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать онлайн пользователей в вашей общине', 'xenword' ) )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$dependencies = new XenForo_Dependencies_Public();

		$dependencies->preLoadData();

		/** @var  $sessionModel XenForo_Model_Session */
		$sessionModel = XenForo_Model::create( 'XenForo_Model_Session' )->getModelFromCache('XenForo_Model_Session');

		$visitor = XenWord::getVisitor();

		/** Pull onlineUsers */
		$onlineUsers = $sessionModel->getSessionActivityQuickList(
			$visitor->toArray(),
			array( 'cutOff' => array( '>', $sessionModel->getOnlineStatusTimeout() ) ),
			( $visitor['user_id'] ? $visitor->toArray() : null )
		);

		echo "<span class='xenword-onlineusers'>";
		echo 'Total: ' . $onlineUsers['total'] . ' (members ' . $onlineUsers['members'] . ', guests: ' . $onlineUsers['guests'] . ', robots: ' . $onlineUsers['robots'] . ')';
		echo "</span><br />";

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Community Information', 'xenword' );
		}

		$defaults = array('title' => '');
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>


	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';

		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXFUsers");' )
);

// End xenword-xf-onlineusers-widget.php