<?php

/**
 * File Name: xenword-xf-resource-widget.php
 *
 * Description: Show the last five resources in a linked XenForo community
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.1.03
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XFResources extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_resource_widget',

			// Widget name will appear in UI
			__('XenForo Resources', 'xenword'),

			// Widget description
			array( 'description' => __( 'Показать последние ресурсы в вашей общине', 'xenword' ) )
		);
	}

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$xenresources = $instance['numberresources'];

		/**
		 * Script to pull the latest updated resources from the XF Resource Manager
		 * @var $resModel  XenResource_Model_Resource
		 */
		$resModel = XenForo_Model::create( 'XenResource_Model_Resource' );

		// @todo Make options
		$fetchOptions = array( 'limit' => $xenresources, 'order' => 'resource_date', 'direction' => 'desc' );

		$rmupdates = $resModel->getResources( array(), $fetchOptions );

		foreach ( $rmupdates AS $rmupdate ) {
			echo(

				"<div class='entry-meta'><a href='"
			     . XenForo_Link::buildPublicLink( 'canonical:resources', $rmupdate )
			     . "' >"
			     . XenForo_Helper_String::wholeWordTrim( $rmupdate['title'], 40 )
			     . "</a><br /></div>"
			);
		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Community Resources', 'xenword' );
		}

		$defaults = array('numberresources' => '5', 'title'=>'');

		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>

			<label for="<?php echo $this->get_field_id( 'numberresources' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'numberresources' ); ?>" name="<?php echo $this->get_field_name( 'numberresources' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberresources'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberresources'] = $new_instance['numberresources'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XFResources");' )
);

// End xenword-xf-resource-widget.php