<?php

/**
 * File Name: xenword-xf-showcase-widget.php
 *
 * Description: Shows the last five reviews in Showcase
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 1.0.7.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordShowcaseItems extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_showcase_items_widget',

			// Widget name will appear in UI
			__( 'XenWord Рекламные товары', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показывать рекламные элементы в вашей общине', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$number_of_showcase_items = $instance['numbershowcaseitems'];

		/** Script to pull the latest Showcase items from the Showcase add-on */

		/** @var $review_qry XenWordShowcaseItems */
		$showcase_item_qry = '
			            SELECT item_id, item_name, last_update, cover_image_id FROM `xf_nflj_showcase_item`
			            WHERE item_state = 1
			            ORDER BY `last_update` DESC
			            LIMIT ' . $number_of_showcase_items . '
						';

		$xenword_showcase_items = XenForo_Application::get( 'db' )->fetchAll( $showcase_item_qry );

		foreach ( $xenword_showcase_items AS $xenword_showcase_item ) {

			/**
			 * item_id & item_name are showing properly
			 * TODO - grab the cover_image_id and show image
			 */

			echo(
				"<div class='entry-meta'><img src='"
				. XenWord::getBoardUrl()
				. "/data/showcase/0/"
				. $xenword_showcase_item['cover_image_id']
				. '-2480db51e2e38ccf10142e9d54cb7762'
				. ".jpg'/>"
				. "<br /><a href='"
				. XenWord::getBoardUrl()
				. '/showcase/'
				. $xenword_showcase_item['item_id']
				. "'>"
				. XenForo_Helper_String::wholeWordTrim( $xenword_showcase_item['item_name'], 40 )
				. "</a></div>"
			);

		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Community Showcase Items', 'xenword' );
		}

		$defaults = array( 'numbershowcaseitems' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'numbershowcaseitems' ); ?>">Количество элементов витрины:</label>
			<select id="<?php echo $this->get_field_id( 'numbershowcaseitems' ); ?>"
			        name="<?php echo $this->get_field_name( 'numbershowcaseitems' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numbershowcaseitems'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance                = array();
		$instance['title']       = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numbershowcaseitems'] = $new_instance['numbershowcaseitems'];

		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordShowcaseItems");' )
);

// End xenword-xf-showcase-items-widget.php