<?php

/**
 * File Name: xenword-xf-thread-all-forums-widget.php
 *
 * Description: Shows the last five posts in the community connect created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.0.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFPosts extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_thread_widget',

			// Widget name will appear in UI
			__( 'XenForo Темы все форумы', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать последние темы из всех форумов в вашей общине', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 * @throws XenForo_Exception
	 * @throws Zend_Exception
	 */
	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var $forumModel XenForo_Model_Forum */
		$forumModel = XenForo_Model::create('XenForo_Model_Forum');

		$visitor = XenWord::getVisitor();

		$permissionCombinationId = $visitor['permission_combination_id'];

		/** @var $threadsModel XenForo_Model_Thread */
		$threadsModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache('XenForo_Model_Thread');
		$threads = $threadsModel->getThreads(array('discussion_state' => 'visible', 'permissionCombinationId' => $permissionCombinationId), array('limit' => $instance['numberposts']*3, 'order' => 'thread_id', 'orderDirection' => 'desc') );

		ob_start();

		$i = 0;

		foreach ( $threads AS $thread ) {

			$visitor->setNodePermissions( $thread['node_id'], $thread['node_permission_cache'] );

			if ( $forumModel->canViewForum( $thread ) ) {

				if ( $i == $instance['numberposts']  ) break;

					// Use this function to display the avatar where ever you want.
					echo ("<div class='threadListAvatar'>" . get_avatar( $thread['user_id'], 35 ) . " </div>");

					echo(
						"<div class='threadListItem'><a href='"
						. XenForo_Link::buildPublicLink( 'canonical:threads', $thread )
						. "'>"
						. XenForo_Helper_String::wholeWordTrim( $thread['title'], 40 )
						. "</a>"
					);



					echo '<br />posted ' . date_i18n(get_option('date_format'), $thread['post_date']);

					$node = XenForo_Model::create('XenForo_Model_Node')->getNodeById($thread['node_id']);

					echo ' in ' . $node['title'];

					// echo date('m-d-Y', strtotime($thread['post_date']));

					echo '</div>';

					$i++;

			}
		}

		echo '<span style="float:right"><a href="' . XenWord::getBoardUrl() . '/find-new/posts">Просмотр потоков</a></span><br />';

		ob_end_flush();

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Community Threads All Forums', 'xenword' );
		}

		$defaults = array( 'numberposts' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'numberposts' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'numberposts' ); ?>"
			        name="<?php echo $this->get_field_name( 'numberposts' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberposts'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	/**
	 * Updating widget replacing old instances with new
	 *
	 * @param array $new_instance
	 * @param array $old_instance
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                = array();
		$instance['title']       = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberposts'] = $new_instance['numberposts'];

		return $instance;
	}
}

add_action( 'widgets_init', function(){
	register_widget( 'XenWordXFPosts' );
});

// End xenword-xf-thread-all-forums-widget.php