<?php

/**
 * File Name: xenword-xf-thread-by-forum-widget.php
 *
 * Description: Shows the last five posts in a particular XenForo forum
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 2.0.2.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFPostsByForum extends WP_Widget {

	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'xenword_xf_thread_new_widget',

			// Widget name will appear in UI
			__( 'XenForo темы на форуме', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать последние темы в вашей общине. Возможность установить форум.', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$number_of_posts = $instance['numberposts'];

		/** Script to pull the latest posts from the XF Forum */

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create( 'XenForo_Model_Thread' )->getModelFromCache( 'XenForo_Model_Thread' );

		$forum = $instance['forumnumber'];

		$conditions = array();

		$fetchOptions = array(
			'join' => XenForo_Model_Thread::FETCH_FIRSTPOST,
			'order' => 'post_date',
			'orderDirection' => 'desc',
			'discussion_state' => 'visible',
			'limit' => $number_of_posts*3
		);

		$threads = $threadModel->getThreadsInForum( $forum, $conditions, $fetchOptions );

		$i = 0;

		foreach ( $threads AS $threadId => $thread ) {

			if ( $threadModel->canViewThread( $thread, $thread ) ) {

				if ( $i == $instance['numberposts']  ) break;

				echo(
					"<div class='entry-meta'><a href='"
					. XenForo_Link::buildPublicLink( 'canonical:threads', $thread )
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $thread['title'], 40 )
					. "</a></div>"
				);

				$i++;

			}
		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Community Threads', 'xenword' );
		}

		$forum = $instance['forumnumber'];

		$defaults = array( 'forumnumber' => '2', 'title' => '' );

		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'forumnumber' ); ?>"><?php _e( 'Форум ID:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'forumnumber' ); ?>" name="<?php echo $this->get_field_name( 'forumnumber' ); ?>" type="text" value="<?php echo esc_attr( $forum ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'numberposts' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'numberposts' ); ?>"
			        name="<?php echo $this->get_field_name( 'numberposts' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberposts'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberposts'] = $new_instance['numberposts'];
		$instance['forumnumber'] = $new_instance['forumnumber'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXFPostsByForum");' )
);

// End xenword-xf-thread-by-forum-widget.php