<?php

/**
 * File Name: xenword-xf-feature-thread-widget.php
 *
 * Description: Shows a thread created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.03.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordFeatureThread extends WP_Widget {

	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'xenword_feature_thread_widget',

			// Widget name will appear in UI
			__('XenForo Рекомендуемые резьба', 'xenword_text-domain'),

			// Widget description
			array( 'description' => __( 'Показать XenForo поток от вашего сообщества', 'xenword_text-domain' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		echo '<hr />';
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create( 'XenForo_Model_Thread' )->getModelFromCache('XenForo_Model_Thread');
		$featured_thread = $threadModel->getThreadById( $instance['show_threads'], array( 'join' => XenForo_Model_Thread::FETCH_FIRSTPOST ) );

		$formatter = XenForo_BbCode_Formatter_Base::create();

		$parser = new XenForo_BbCode_Parser($formatter);

		/** @var $html XenForo_Application */
		$html = $parser->render( XenForo_Helper_String::wholeWordTrim( $featured_thread['message'] , XenForo_Application::get('options')->discussionRssContentLength ) );

		echo ('<div class="entry-meta subHeading categoryStrip"><a href="' . XenForo_Link::buildPublicLink( 'canonical:threads', $instance['show_threads'] ) . 'threads/' . $instance['show_threads'] . '">' .  XenForo_Helper_String::wholeWordTrim($featured_thread['title'], 48) . '</a> <br /><br /></div>');

		echo $html .'<br /><hr />';

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Есть поток', 'xenword_text-domain' );
		}

		$select_thread['title'] = $instance['show_threads'];

		$defaults = array( 'show_threads' => '', 'show_forum_number' => '', 'title' => '' );

		$instance = wp_parse_args( (array) $instance, $defaults );

		/** @var  $forumModel XenForo_Model_Forum */
		$forumModel = XenForo_Model::create('XenForo_Model_Forum')->getModelFromCache('XenForo_Model_Forum');
		$feature_nodes = $forumModel->getForums(array('display_in_list' => 1 ) );

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache('XenForo_Model_Thread');
		$select_threads = $threadModel->getThreads(array('node_id' => $instance['show_forum_number'], 'discussion_state' => 'visible'), array('limit' => 50, 'order' => 'thread_id', 'orderDirection' => 'desc') );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_forum_number' ); ?>">Форум:</label>
			<select id="<?php echo $this->get_field_id( 'show_forum_number' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_forum_number' ); ?>">
				<?php foreach ( $feature_nodes AS $feature_node ) {
					echo '<option value="' . $feature_node['node_id'] . '"';
					if ( $feature_node['node_id'] == $instance['show_forum_number'] ) {
						echo ' selected="selected"';
					}
					echo '>' . XenForo_Helper_String::wholeWordTrim( $feature_node['title'] , 38 ) . '</option>';
				} ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_threads' ); ?>">Тема:</label>
			<select id="<?php echo $this->get_field_id( 'show_threads' ); ?>"
			        name="<?php echo $this->get_field_name( 'show_threads' ); ?>">
				<?php foreach ( $select_threads AS $select_thread ) {
					echo '<option value="' . $select_thread['thread_id'] . '"';
					if ( $select_thread['thread_id'] == $instance['show_threads'] ) {
						echo ' selected="selected"';
					}
					echo '>' . XenForo_Helper_String::wholeWordTrim( $select_thread['title'] , 38 ) . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['show_threads'] = $new_instance['show_threads'];
		$instance['show_forum_number'] = $new_instance['show_forum_number'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordFeatureThread");' )
);

// End xenword-xf-feature-thread-widget.php