<?php

/**
 * File Name: xenword-xf-thread-popular-widget.php
 *
 * Description: Shows the most popular posts in the community connect created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes
 *
 * @since 1.0.02.02
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFPopularPosts extends WP_Widget {

	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'xenword_xf_popular_thread_widget',

			// Widget name will appear in UI
			__('XenForo Popular Threads', 'xenword'),

			// Widget description
			array( 'description' => __( 'Показать самые популярные темы в вашем сообществе', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** Script to pull the most popular posts from the XF Forum */

		/** @var  $forumModel XenForo_Model_Forum */
		$forumModel = XenForo_Model::create('XenForo_Model_Forum');

		$visitor = XenWord::getVisitor();

		$permissionCombinationId = $visitor['permission_combination_id'];

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create('XenForo_Model_Thread')->getModelFromCache('XenForo_Model_Thread');
		$threads = $threadModel->getThreads(array('discussion_state' => 'visible', 'permissionCombinationId' => $permissionCombinationId), array('limit' => $instance['popularposts']*3, 'order' => 'view_count', 'orderDirection' => 'desc') );

		$i = 0;

		foreach ( $threads AS $thread ) {

			$visitor->setNodePermissions( $thread['node_id'], $thread['node_permission_cache'] );

			if ( $forumModel->canViewForum( $thread ) ) {

				if ( $i == $instance['popularposts'] ) break;

				echo(
					"<div class='entry-meta'><a href='"
					. XenForo_Link::buildPublicLink( 'canonical:threads', $thread )
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $thread['title'], 40 )
					. "</a></div>"
				);

				$i ++;
			}

		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'Популярные темы', 'xenword' );
		}

		$defaults = array('popularposts' => '5', 'title'=>'');
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>

		<label for="<?php echo $this->get_field_id( 'popularposts' ); ?>">Число постов:</label>
	    <select id="<?php echo $this->get_field_id( 'popularposts' ); ?>" name="<?php echo $this->get_field_name( 'popularposts' ); ?>">
	    <?php for ( $i = 1; $i <= 20; $i ++ ) {
				echo '<option value="' . $i . '"';
				if ( $i == $instance['popularposts'] ) {
					echo ' selected="selected"';
				}
				echo '>' . $i . '</option>';
			} ?>
	    </select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['popularposts'] = $new_instance['popularposts'];
		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXFPopularPosts");' )
);

// End xenword-xf-thread-popular-widget.php