<?php

/**
 * File Name: xenword-xf-thread-replies-widget.php
 *
 * Description: Shows the last five posts with replies in the community connect created by XenForo
 *
 * @author      LPH
 * @version     2.5.0.03
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.0.01
 *
 * Suggestions by theDoz3R
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXFPostsReplies extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_thread_replies_widget',

			// Widget name will appear in UI
			__( 'XenForo потоки с ответами', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать последние потоки с ответами', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 * @throws Zend_Exception
	 */
	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( !empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		/** @var  $threadModel XenForo_Model_Thread */
		$threadModel = XenForo_Model::create( 'XenForo_Model_Thread' )->getModelFromCache('XenForo_Model_Thread');

		$number_of_posts = ($instance['numberposts'])*3 ;

		/** Script to pull the latest posts from the XF Forum */

		/** @var $thread_qry XenWordXFPosts */
		$thread_qry = "
			            SELECT thread_id, node_id, reply_count, title, last_post_date FROM `xf_thread`
			            WHERE discussion_state = 'visible'
			            ORDER BY `last_post_date` DESC
			            LIMIT $number_of_posts
						";

		$threads = XenForo_Application::get( 'db' )->fetchAll( $thread_qry );

		$i = 0;

		foreach ( $threads AS $thread ) {

			if ( $threadModel->canViewThread( $thread, $thread ) ) {

				$forum_id = $thread['node_id'];
				$forum_qry
				          = "
							SELECT title, node_id FROM `xf_node`
							WHERE node_id = $forum_id
							LIMIT $number_of_posts
							";

				$forum = XenForo_Application::get( 'db' )->fetchAll( $forum_qry );
				$forum = $forum[0];
				$link = XenForo_Link::buildPublicLink( 'canonical:threads', $thread );
				$forum_link = XenForo_Link::buildPublicLink( 'canonical:forums', $forum );

				if ( $i == $instance['numberposts']  ) break;

				echo(
					"<div class='entry-meta'><a href='"
					. $link
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $thread['title'], 40 )
					. "</a> replies: <a href='"
					. $link
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $thread['reply_count'], 6 )
					. "</a> on <a href='"
					. $forum_link
					. "'>"
					. XenForo_Helper_String::wholeWordTrim( $forum['title'], 40 )
					. "</a> </div>"
				);

				$i++;
			}
		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 *
	 * @return string|void
	 */
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Темы сообщества с ответами', 'xenword' );
		}

		$defaults = array( 'numberposts' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'numberposts' ); ?>">Число постов:</label>
			<select id="<?php echo $this->get_field_id( 'numberposts' ); ?>"
			        name="<?php echo $this->get_field_name( 'numberposts' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberposts'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>
		</p>

	<?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 *
	 * @return array $instance
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                = array();
		$instance['title']       = ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberposts'] = $new_instance['numberposts'];

		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXFPostsReplies");' )
);

// End xenword-xf-thread-replies-widget.php