<?php

/**
 * File Name: xenword-xf-user-info-widget.php
 * Description: Shows the role the current user has. This is for diagnostics.
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.0.09
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenForoUserInfo extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_user_widget',

			// Widget name will appear in UI
			__( 'XenForo текущего пользователя информация', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Сведения о XenForo текущего пользователя. Это для диагностики только.', 'xenword' ), )
		);
	}

	public function widget($args, $instance) { // widget sidebar output
		extract($args, EXTR_SKIP);
		/** @var  $before_widget */
		echo $before_widget; // pre-widget code from theme

		global $current_user, $wp_roles;

		if ( is_user_logged_in() ) {

			/**
			 * @todo Add links to support, FAQs, etc
			 */

			echo '<strong>Информация о WordPress:</strong> <br />';

			echo 'Логин имя пользователя: ' . $current_user->user_login . '<br />';
			echo 'Пользователь email: ' . $current_user->user_email . '<br />';

			echo 'Отображаемое имя: ' . $current_user->display_name . '<br />';

			foreach ( $wp_roles->role_names as $role => $name ) :

				if ( current_user_can( $role ) )
					echo 'Этот пользователь имеет роль ' . $role . '<br />';

			endforeach;

			echo '<br />';

			echo get_avatar( $current_user->user_email, $size = '50', $default = '<path_to_url>' );

			echo '<br /><br /><br /><br />';

			echo '<strong>XenForo Информация:</strong><br />';

			$visitor = XenWord::getVisitor();

			echo 'user_id is ' . $visitor->get('user_id');
			echo '<br />';

			echo 'Логин имя пользователя: ' . $visitor->get('username') . '<br />';
			echo 'Пользователь email: ' . $visitor->get('email') . '<br />';

			echo $visitor->get('about');

			$xenword_options = get_option( 'xenword_options' );

			// This is an array
			$userGroupIds = $visitor['secondary_group_ids'];

			$userGroups = explode(',', $userGroupIds);

			foreach ( $userGroups as $userGroupId ) {

				$xf_role = 'xf_role_' . $userGroupId;

				$wp_role = $xenword_options[$xf_role];

				echo '<br />WP Role: ' . $wp_role;

			}

			echo '<br /><br />Оповещения ' . $visitor->get('alerts_unread');

			echo '<br />Непрочитанные сообщения ' . $visitor->get('conversations_unread');

			echo '<br /><br /><strong>XenForo Root</strong>';

			echo '<br />' . XenForo_Autoloader::getInstance()->getRootDir();

			echo '<br /><br />';

			echo get_avatar( get_current_user_id(), 28 );

			echo '<br /><br /><br />';

		} else {
			echo 'Не вошли в WordPress';
		}

		/** @var  $after_widget */
		echo $after_widget; // post-widget code from theme
	}
}

add_action(
	'widgets_init',
	create_function('','return register_widget("XenForoUserInfo");')
);

// End of xenword-xf-user-info-widget.php