<?php

/**
 * File Name: xenword-xf-xenproduct-widget.php
 *
 * Description: Shows the last products available in the XenProduct Store
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 2.5.0.04
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXenProduct extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_product_widget',

			// Widget name will appear in UI
			__( 'XenWord Магазин элементы', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать последние элементы продукта в магазине XenProduct', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */
	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$limit = $instance['numberofitems'];

		/**
		 * Query to pull product titles and state
		 */

		/** @var  $product_qry XenWordXenProduct */
		$product_qry = "
			SELECT product_id, product_title, product_state, display_order, download_count, price FROM xenproduct_product
			WHERE product_state = 'visible'
			ORDER BY display_order ASC
			LIMIT $limit
		";

		$products = XenForo_Application::get( 'db' )->fetchAll( $product_qry );

		foreach ( $products as $product ) {
			echo '<a href="' . XenWord::getBoardUrl() . '/products/'  . $product['product_id'] . '">' . $product['product_title'] . '</a>' . ' ( $' . $product['price'] . ' )' .  '<br />';
		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'XenProduct Store Items', 'xenword' );
		}

		$defaults = array( 'numberofitems' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'numberofitems' ); ?>">Число должностей:</label>
			<select id="<?php echo $this->get_field_id( 'numberofitems' ); ?>"
			        name="<?php echo $this->get_field_name( 'numberofitems' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberofitems'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberofitems'] = $new_instance['numberofitems'];

		return $instance;
	}
}

add_action( 'widgets_init', function(){
	register_widget( 'XenWordXenProduct' );
});

// End xenword-xf-product-widget.php