<?php

/**
 * File Name: xenword-xf-xenreviews-widget.php
 * Description: Shows the last five reviews in XenReviews
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.4.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXenReviewItems extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xf_xenreviews_items-widget',

			// Widget name will appear in UI
			__( 'XenReview Items', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать отзывы в вашем сообществе', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$number_of_review_items = $instance['number_of_review_items'];

		/** Script to pull the latest review items from the XenReviews */

		/** @var $review_qry XenWordXenReviewItems */
		$item_review_qry = "
			            SELECT item_id, title, post_date, url_chunk FROM `xf_xr_item`
			            WHERE discussion_state = 'visible'
			            ORDER BY `post_date` DESC
			            LIMIT ' . $number_of_review_items . '
						";

		$xenword_item_reviews = XenForo_Application::get( 'db' )->fetchAll( $item_review_qry );

		foreach ( $xenword_item_reviews AS $xenword_item_review ) {

			echo(
				"<div class='entry-meta'><img src='"
				. XenWord::getBoardUrl()
				. "/data/logos/l/0/"
				. $xenword_item_review['item_id']
				. ".jpg'/>"
				. "<br /><a href='"
				. XenWord::getBoardUrl()
				. '/reviews/'
				. $xenword_item_review['url_chunk']
				. '/'
				. $xenword_item_review['item_id']
				. "'>"
				. XenForo_Helper_String::wholeWordTrim( $xenword_item_review['title'], 40 )
				. "</a></div>"
			);

		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Сообщество обзор элементов', 'xenword' );
		}

		$defaults = array( 'number_of_review_items' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Название:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>


			<label for="<?php echo $this->get_field_id( 'number_of_review_items' ); ?>">Количество отзывов:</label>
			<select id="<?php echo $this->get_field_id( 'number_of_review_items' ); ?>"
			        name="<?php echo $this->get_field_name( 'number_of_review_items' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['number_of_review_items'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance                = array();
		$instance['title']       = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['number_of_review_items'] = $new_instance['number_of_review_items'];

		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXenReviewItems");' )
);

// End xenword-xf-xenreviews-items-widget.php