<?php

/**
 * File Name: xenword-xf-xenreviews-widget.php
 *
 * Description: Shows the last five reviews in XenReviews
 *
 * @author      LPH
 * @version     2.5.0.04
 * @package     XenWord
 * @subpackage  includes/widgets
 *
 * @since 1.0.4.01
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

class XenWordXenReviews extends WP_Widget {

	public function __construct() {
		parent::__construct(
		// Base ID of your widget
			'xenword_xenreviews_widget',

			// Widget name will appear in UI
			__( 'XenForo Reviews', 'xenword' ),

			// Widget description
			array( 'description' => __( 'Показать последние отзывы в вашем сообществе', 'xenword' ), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 *
	 */

	public function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		extract( $args, EXTR_SKIP );

		/** @var $before_widget */
		echo $before_widget; // pre-widget code from theme

		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$number_of_reviews = $instance['numberreviews'];

		/** Script to pull the latest user reviews from the XenReviews */

		/** @var $review_qry XenWordXenReviews */
		$review_qry = '
			            SELECT review_id, title, post_date FROM `xf_xr_review`
			            WHERE message_state = 1
			            ORDER BY `post_date` DESC
			            LIMIT ' . $number_of_reviews . '
						';

		$xenword_reviews = XenForo_Application::get( 'db' )->fetchAll( $review_qry );

		foreach ( $xenword_reviews AS $xenword_review ) {

			echo(
				"<div class='entry-meta'><a href='"
				. XenWord::getBoardUrl()
				. '/reviews/user-reviews/'
				. $xenword_review['review_id']
				. "'>"
				. XenForo_Helper_String::wholeWordTrim( $xenword_review['title'], 40 )
				. "</a></div>"
			);

		}

		/** @var $after_widget */
		echo $after_widget; // post-widget code from theme
	}

	// Widget Backend
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		} else {
			$title = __( 'Community Reviews', 'xenword' );
		}

		$defaults = array( 'numberreviews' => '5', 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
			       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
			       value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<p>

			<label for="<?php echo $this->get_field_id( 'numberreviews' ); ?>">Number of reviews:</label>
			<select id="<?php echo $this->get_field_id( 'numberreviews' ); ?>"
			        name="<?php echo $this->get_field_name( 'numberreviews' ); ?>">
				<?php for ( $i = 1; $i <= 20; $i ++ ) {
					echo '<option value="' . $i . '"';
					if ( $i == $instance['numberreviews'] ) {
						echo ' selected="selected"';
					}
					echo '>' . $i . '</option>';
				} ?>
			</select>

		</p>

	<?php
	}

	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numberreviews'] = $new_instance['numberreviews'];

		return $instance;
	}
}

add_action(
	'widgets_init',
	create_function( '', 'return register_widget("XenWordXenReviews");' )
);

// End xenword-xf-xenreviews-widget.php