<?php

/**
 * XenWord: A simple bridge between XenForo and WordPress
 *
 * A simple bridge with options to log into WordPress with XenForo accounts.
 * XenForo threads may be created automatically after a WordPress post, page,
 * or custom post is created. Thread replies may be shown as WordPress comments.
 * This bridge is under constant, incremental development.
 *
 * @todo  This version is for improving WordPress integration on the XenForo side
 *
 * WordPress:       Tested up to 4.5-alpha
 * XenForo:         Tested up to 1.5.5
 *
 * Last Change:     02/20/2016
 *
 * Plugin Name:     XenWord
 * Plugin URI:      http://www.xenword.com
 * Description:     XenWord is a simple, incrementally developed bridge between XenForo and WordPress.
 * Author:          Tux Reports Network
 * Author URI:      http://www.tuxreports.com
 * Version:         3.3.1
 * Text Domain:     xenword
 * Domain Path:     WordPress/languages
 *
 * @package         xenword
 * @author          LPH <layne.heiny@gmail.com>
 * @author          RLL
 * @license         This program is not free software. Do not copy or redistribute.
 *                  A link to xenword.com should remain functioning.
 *                  A branding free license is available in the store.
 * @copyright       2013-2016 Tux Reports Network
 */

/**
 * This section is for security. Do not modify this part:
 * @ignore
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/** Load class XenWord_Versions and checks minimum PHP and WP requirements */
require_once dirname( __FILE__ ) . '/WordPress/includes/class-xenword-versions.php';
XenWord_Versions::check( $wp = '4.2', $php = '5.3' );

/** Load classes Xenword_Loader, Xenword_Activator, Xenword_Deactivator */
require_once dirname( __FILE__ ) . '/WordPress/includes/class-xenword-loader.php';

/**
 * Call activation hook and modify the mysql database tables
 *
 * Call the code that runs during plugin activation.
 * This action is documented in /WordPress/includes/class-xenword-activator.php
 */
function activate_xenword() {
	require_once dirname( __FILE__ ) . '/WordPress/includes/class-xenword-activator.php';
	XenWord_Activator::activate();
}

/**
 * Call deactivation hook
 *
 * The code that runs during plugin deactivation.
 * This action is documented in /WordPress/includes/class-xenword-deactivator.php
 */
function deactivate_xenword() {
	require_once dirname( __FILE__ ) . '/WordPress/includes/class-xenword-deactivator.php';
	XenWord_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_xenword' );
register_deactivation_hook( __FILE__, 'deactivate_xenword' );

/** Load the XenWord plugin action links */
require_once dirname( __FILE__ ) . '/WordPress/admin/includes/class-xenword-action-links.php';

/** Load the XenWord admin notices */
require_once dirname( __FILE__ ) . '/WordPress/admin/includes/class-xenword-admin-notices.php';

/** Load the XenWord options set in XenWord settings panel */
$xenword_options = get_option( 'xenword_options' );

/** Load the XenWord class only if the XenForo path in XenWord settings panel is accurate */
if ( isset( $xenword_options['absolute_path'] ) && file_exists( $xenword_options['absolute_path'] . '/library/XenForo/Autoloader.php' ) ) {

	/**
	 * Require the XenWord class located XenForo/index.php
	 * This file contains the getXenForo function
	 */
	require_once dirname( __FILE__ ) . '/XenForo/index.php';
	require_once dirname( __FILE__ ) . '/XenForo/library/XenWord/Autoloader.php';

	/**
	 * Load other functions if pluggable functions haven't already been defined
	 *
	 * http://codex.wordpress.org/Pluggable_Functions
	 */
	if ( ! function_exists( 'get_currentuserinfo' ) ) {
		require_once dirname( __FILE__ ) . '/WordPress/includes/class-xenword-includes.php';
	}
}

// End xenword.php